/// <reference types="ignite-ui" />
import { ElementRef, IterableDiffers, KeyValueDiffers, ChangeDetectorRef, Renderer2 } from '@angular/core';
import { IgContentControlBase } from '../igcontrolbase/igcontentcontrolbase';
import * as i0 from "@angular/core";
export declare class IgDialogComponent extends IgContentControlBase<IgDialog> {
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef);
    /**
     * Destroys the igDialog and moves the target element to its original parent.
     */
    destroy(): object;
    /**
     * Gets/Sets the state of the editor.
     * 				Note: If the state of the dialog changes, then stateChanging and stateChanged events are raised.
     *
     * @param state     New state.
     */
    state(state?: string): string;
    /**
     * Gets reference to the dynamically created DIV element which represents the dialog.
     */
    mainElement(): Element;
    /**
     * Closes the dialog if it is opened.
     * 				Notes:
     * 				1. If the state of the dialog changes, then stateChanging and stateChanged events are raised.
     * 				2. That method does not change minimized or maximized state of the dialog.
     * 				It means that method "open" will open the dialog and keep previous minimized or maximized state.
     *
     * @param e     Browser event: internal use only.
     */
    close(e?: object): object;
    /**
     * Opens the dialog if it is closed. Notes:
     * 				1. If the state of the dialog changes, then stateChanging and stateChanged events are raised.
     * 				2. That method does not change minimized or maximized state of the dialog.
     * It means that if the dialog was in minimized or maximized stated when closed by "close" method,
     * then the dialog will open in minimized or maximized state respectively.
     */
    open(): object;
    /**
     * Minimizes the dialog if it is not minimized.
     * 				Note: If the state of the dialog changes, then stateChanging and stateChanged events are raised.
     */
    minimize(): object;
    /**
     * Maximizes the dialog if it is not maximized.
     * 				Note: If the state of the dialog changes, then stateChanging and stateChanged events are raised.
     */
    maximize(): object;
    /**
     * Sets the normal state for the dialog if it was maximized or minimized.
     * 				Note: If the state of the dialog changes, then stateChanging and stateChanged events are raised.
     */
    restore(): object;
    /**
     * Pins the dialog if it is not pinned.
     * 				When the dialog is pinned, then the html element of the dialog is moved to the original container where the target elemen
     *  was located and position:absolute is removed.
     * 				The pinned dialog does not support modal state, maximized state and it can not be moved.
     * 				Notes:
     * 				1. If the parent element of the original target-element is invisible, then the pinned dialog becomes invisible as well.
     * 				2. If the state of the dialog changes, then stateChanging and stateChanged events are raised.
     */
    pin(): object;
    /**
     * Unpins the dialog if it is pinned.
     * 				Note: If the state of the dialog changes, then stateChanging and stateChanged events are raised.
     */
    unpin(): object;
    /**
     * Gets a reference to the top modal dialog.
     */
    getTopModal(): object;
    /**
     * Checks if the dialog is modal and if it is currently active.
     */
    isTopModal(): boolean;
    /**
     * Moves a not modal dialog to the top.
     *
     * @param e     Original event of browser.
     */
    moveToTop(e?: object): object;
    /**
     * Retrieves the igDialog content container or sets its content to be the new content provided.
     *
     * @param newContent     The new html content provided as a string. If the parameter is provided then the method acts as a setter.
     */
    content(newContent?: string): object;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgDialogComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgDialogComponent, "ig-dialog", never, { "widgetId": { "alias": "widgetId"; "required": false; }; "options": { "alias": "options"; "required": false; }; "changeDetectionInterval": { "alias": "changeDetectionInterval"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "create": { "alias": "create"; "required": false; }; "mainElement": { "alias": "mainElement"; "required": false; }; "state": { "alias": "state"; "required": false; }; "pinned": { "alias": "pinned"; "required": false; }; "closeOnEscape": { "alias": "closeOnEscape"; "required": false; }; "showCloseButton": { "alias": "showCloseButton"; "required": false; }; "showMaximizeButton": { "alias": "showMaximizeButton"; "required": false; }; "showMinimizeButton": { "alias": "showMinimizeButton"; "required": false; }; "showPinButton": { "alias": "showPinButton"; "required": false; }; "pinOnMinimized": { "alias": "pinOnMinimized"; "required": false; }; "imageClass": { "alias": "imageClass"; "required": false; }; "headerText": { "alias": "headerText"; "required": false; }; "showHeader": { "alias": "showHeader"; "required": false; }; "showFooter": { "alias": "showFooter"; "required": false; }; "footerText": { "alias": "footerText"; "required": false; }; "dialogClass": { "alias": "dialogClass"; "required": false; }; "container": { "alias": "container"; "required": false; }; "height": { "alias": "height"; "required": false; }; "width": { "alias": "width"; "required": false; }; "minHeight": { "alias": "minHeight"; "required": false; }; "minWidth": { "alias": "minWidth"; "required": false; }; "maxHeight": { "alias": "maxHeight"; "required": false; }; "maxWidth": { "alias": "maxWidth"; "required": false; }; "draggable": { "alias": "draggable"; "required": false; }; "position": { "alias": "position"; "required": false; }; "resizable": { "alias": "resizable"; "required": false; }; "tabIndex": { "alias": "tabIndex"; "required": false; }; "openAnimation": { "alias": "openAnimation"; "required": false; }; "closeAnimation": { "alias": "closeAnimation"; "required": false; }; "zIndex": { "alias": "zIndex"; "required": false; }; "modal": { "alias": "modal"; "required": false; }; "trackFocus": { "alias": "trackFocus"; "required": false; }; "closeButtonTitle": { "alias": "closeButtonTitle"; "required": false; }; "minimizeButtonTitle": { "alias": "minimizeButtonTitle"; "required": false; }; "maximizeButtonTitle": { "alias": "maximizeButtonTitle"; "required": false; }; "pinButtonTitle": { "alias": "pinButtonTitle"; "required": false; }; "unpinButtonTitle": { "alias": "unpinButtonTitle"; "required": false; }; "restoreButtonTitle": { "alias": "restoreButtonTitle"; "required": false; }; "temporaryUrl": { "alias": "temporaryUrl"; "required": false; }; "enableHeaderFocus": { "alias": "enableHeaderFocus"; "required": false; }; "enableDblclick": { "alias": "enableDblclick"; "required": false; }; }, { "stateChanging": "stateChanging"; "stateChanged": "stateChanged"; "animationEnded": "animationEnded"; "focus": "focus"; "blur": "blur"; }, never, ["*"], false, never>;
}
