/// <reference types="ignite-ui" />
import { ElementRef, IterableDiffers, KeyValueDiffers, ChangeDetectorRef, Renderer2 } from '@angular/core';
import { IgEditorBase } from './igeditorbase';
import { NgModel } from '@angular/forms';
import * as i0 from "@angular/core";
export declare class IgCurrencyEditorComponent extends IgEditorBase<IgCurrencyEditor> {
    model: NgModel;
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef, model: NgModel);
    /**
     * Gets/sets a string that is used as the currency symbol shown with the number in the input.
     * The value provided as a param is propagated to the currencySymbol option and thus has the same priority as the option.
     *
     * @param symbol New currency symbol.
     */
    currencySymbol(symbol?: object): string;
    /**
     * Gets/Sets editor value.
     *
     * @param newValue New editor value.
     */
    value(newValue?: number): number;
    /**
     * Finds index of list item by text that matches with the search parameters.
     *
     * @param value The text to search for.
     */
    findListItemIndex(value: number): number;
    getSelectedText(): void;
    getSelectionStart(): void;
    getSelectionEnd(): void;
    /**
     * Increments value in editor according to the parameter or selects the previous item from the drop-down list if
     * [isLimitedToListValues](ui.%%WidgetNameLowered%%#options:isLimitedToListValues) is enabled.
     *
     * @param delta Increments value.
     */
    spinUp(delta?: number): void;
    /**
     * Decrements value in editor according to the parameter selects the next item from the drop-down list if
     * [isLimitedToListValues](ui.%%WidgetNameLowered%%#options:isLimitedToListValues) is enabled.
     *
     * @param delta Decrement value.
     */
    spinDown(delta?: number): void;
    /**
     * This method is deprecated in favor of [spinUp](ui.%%WidgetNameLowered%%#options:spinUp).
     */
    selectListIndexUp(): void;
    /**
     * This method is deprecated in favor of [spinDown](ui.%%WidgetNameLowered%%#options:spinDown).
     */
    selectListIndexDown(): void;
    /**
     * Gets current regional.
     */
    getRegionalOption(): string;
    /**
     * Changes the the regional settings of widget element to the language specified in
     * [options.regional](ui.ignumericeditor#options:regional)
     * Note that this method is for rare scenarios, use [regional](ui.ignumericeditor#options:regional) option setter
     */
    changeRegional(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgCurrencyEditorComponent, [null, null, null, null, null, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgCurrencyEditorComponent, "ig-currency-editor", never, { "widgetId": { "alias": "widgetId"; "required": false; }; "options": { "alias": "options"; "required": false; }; "changeDetectionInterval": { "alias": "changeDetectionInterval"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "create": { "alias": "create"; "required": false; }; "width": { "alias": "width"; "required": false; }; "height": { "alias": "height"; "required": false; }; "value": { "alias": "value"; "required": false; }; "tabIndex": { "alias": "tabIndex"; "required": false; }; "allowNullValue": { "alias": "allowNullValue"; "required": false; }; "nullValue": { "alias": "nullValue"; "required": false; }; "inputName": { "alias": "inputName"; "required": false; }; "readOnly": { "alias": "readOnly"; "required": false; }; "validatorOptions": { "alias": "validatorOptions"; "required": false; }; "buttonType": { "alias": "buttonType"; "required": false; }; "listItems": { "alias": "listItems"; "required": false; }; "listWidth": { "alias": "listWidth"; "required": false; }; "listItemHoverDuration": { "alias": "listItemHoverDuration"; "required": false; }; "dropDownAttachedToBody": { "alias": "dropDownAttachedToBody"; "required": false; }; "dropDownAnimationDuration": { "alias": "dropDownAnimationDuration"; "required": false; }; "visibleItemsCount": { "alias": "visibleItemsCount"; "required": false; }; "includeKeys": { "alias": "includeKeys"; "required": false; }; "excludeKeys": { "alias": "excludeKeys"; "required": false; }; "textAlign": { "alias": "textAlign"; "required": false; }; "placeHolder": { "alias": "placeHolder"; "required": false; }; "selectionOnFocus": { "alias": "selectionOnFocus"; "required": false; }; "textMode": { "alias": "textMode"; "required": false; }; "spinWrapAround": { "alias": "spinWrapAround"; "required": false; }; "isLimitedToListValues": { "alias": "isLimitedToListValues"; "required": false; }; "revertIfNotValid": { "alias": "revertIfNotValid"; "required": false; }; "preventSubmitOnEnter": { "alias": "preventSubmitOnEnter"; "required": false; }; "dropDownOrientation": { "alias": "dropDownOrientation"; "required": false; }; "maxLength": { "alias": "maxLength"; "required": false; }; "dropDownOnReadOnly": { "alias": "dropDownOnReadOnly"; "required": false; }; "toUpper": { "alias": "toUpper"; "required": false; }; "toLower": { "alias": "toLower"; "required": false; }; "locale": { "alias": "locale"; "required": false; }; "suppressNotifications": { "alias": "suppressNotifications"; "required": false; }; "regional": { "alias": "regional"; "required": false; }; "negativeSign": { "alias": "negativeSign"; "required": false; }; "negativePattern": { "alias": "negativePattern"; "required": false; }; "decimalSeparator": { "alias": "decimalSeparator"; "required": false; }; "groupSeparator": { "alias": "groupSeparator"; "required": false; }; "groups": { "alias": "groups"; "required": false; }; "maxDecimals": { "alias": "maxDecimals"; "required": false; }; "minDecimals": { "alias": "minDecimals"; "required": false; }; "dataMode": { "alias": "dataMode"; "required": false; }; "minValue": { "alias": "minValue"; "required": false; }; "maxValue": { "alias": "maxValue"; "required": false; }; "spinDelta": { "alias": "spinDelta"; "required": false; }; "scientificFormat": { "alias": "scientificFormat"; "required": false; }; "positivePattern": { "alias": "positivePattern"; "required": false; }; "currencySymbol": { "alias": "currencySymbol"; "required": false; }; }, { "rendering": "rendering"; "rendered": "rendered"; "mousedown": "mousedown"; "mouseup": "mouseup"; "mousemove": "mousemove"; "mouseover": "mouseover"; "mouseout": "mouseout"; "blur": "blur"; "focus": "focus"; "keydown": "keydown"; "keypress": "keypress"; "keyup": "keyup"; "valueChanging": "valueChanging"; "valueChanged": "valueChanged"; "dropDownListOpening": "dropDownListOpening"; "dropDownListOpened": "dropDownListOpened"; "dropDownListClosing": "dropDownListClosing"; "dropDownListClosed": "dropDownListClosed"; "dropDownItemSelecting": "dropDownItemSelecting"; "dropDownItemSelected": "dropDownItemSelected"; "textChanged": "textChanged"; }, never, ["*"], false, never>;
}
