/// <reference types="ignite-ui" />
import { ElementRef, IterableDiffers, KeyValueDiffers, ChangeDetectorRef, Renderer2 } from '@angular/core';
import { IgEditorBase } from './igeditorbase';
import { NgModel } from '@angular/forms';
import * as i0 from "@angular/core";
export declare class IgDatePickerComponent extends IgEditorBase<IgDatePicker> {
    model: NgModel;
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef, model: NgModel);
    /**
     * Changes the the regional settings of widget element to the language specified in [options.regional](ui.igdatepicker#options:regional)
     * Note that this method is for rare scenarios, use [regional](ui.igdatepicker#options:regional) option setter
     */
    changeRegional(): void;
    /**
     * Returns a reference to the jQuery calendar used as a picker selector
     */
    getCalendar(): string;
    dropDownContainer(): void;
    findListItemIndex(): void;
    getSelectedListItem(): void;
    selectedListIndex(): void;
    /**
     * Shows the drop down list.
     */
    showDropDown(): void;
    /**
     * Hides the drop down list.
     */
    hideDropDown(): void;
    /**
     * Returns a reference to the calendar button UI element of the editor.
     */
    dropDownButton(): string;
    /**
     * Returns the visibility state of the calendar.
     */
    dropDownVisible(): boolean;
    /**
     * Destroys the widget
     */
    destroy(): void;
    /**
     * Gets/Sets editor value.
     *
     * Note! This option doesn't use the dateInputFormat to extract the date
     *
     * @param newValue New editor value. Date object can be set as value. String value can be passed and the editor will
     * use the javascript Date object constructor to create date object and will use it for the comparison.
     * MVC date format can be used too. For example Date(/"ticks"/).
     */
    value(newValue?: Date): Date;
    /**
     * Gets selected date as a date object. This method can be used when dataMode is set as either displayModeText or editModeText.
     * In such cases the value() method will not return date object and getSelectedDate() can be used to replace that functionality.
     */
    getSelectedDate(): Date;
    /**
     * Sets selected date. This method can be used when dataMode is set as either displayModeText or editModeText.
     * In such cases the value() cannot accept a date object as a new value and getSelectedDate() can be used to replace that functionality.
     *
     * @param date date
     */
    selectDate(date: Date): void;
    /**
     * Increases the date or time period, depending on the current cursor position.
     *
     * @param delta The increase delta.
     */
    spinUp(delta?: number): void;
    /**
     * Decreases the date or time period, depending on the current cursor position.
     *
     * @param delta The decrease delta.
     */
    spinDown(delta?: number): void;
    /**
     * Returns a reference to the spin up UI element of the editor.
     */
    spinUpButton(): string;
    /**
     * Returns a reference to the spin down UI element of the editor.
     */
    spinDownButton(): string;
    /**
     * Checks if the value in the editor is valid. Note: This function will not trigger automatic notifications.
     */
    isValid(): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgDatePickerComponent, [null, null, null, null, null, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgDatePickerComponent, "ig-date-picker", never, { "widgetId": { "alias": "widgetId"; "required": false; }; "options": { "alias": "options"; "required": false; }; "changeDetectionInterval": { "alias": "changeDetectionInterval"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "create": { "alias": "create"; "required": false; }; "width": { "alias": "width"; "required": false; }; "height": { "alias": "height"; "required": false; }; "value": { "alias": "value"; "required": false; }; "tabIndex": { "alias": "tabIndex"; "required": false; }; "allowNullValue": { "alias": "allowNullValue"; "required": false; }; "nullValue": { "alias": "nullValue"; "required": false; }; "inputName": { "alias": "inputName"; "required": false; }; "readOnly": { "alias": "readOnly"; "required": false; }; "validatorOptions": { "alias": "validatorOptions"; "required": false; }; "buttonType": { "alias": "buttonType"; "required": false; }; "listItems": { "alias": "listItems"; "required": false; }; "listWidth": { "alias": "listWidth"; "required": false; }; "listItemHoverDuration": { "alias": "listItemHoverDuration"; "required": false; }; "dropDownAttachedToBody": { "alias": "dropDownAttachedToBody"; "required": false; }; "dropDownAnimationDuration": { "alias": "dropDownAnimationDuration"; "required": false; }; "visibleItemsCount": { "alias": "visibleItemsCount"; "required": false; }; "includeKeys": { "alias": "includeKeys"; "required": false; }; "excludeKeys": { "alias": "excludeKeys"; "required": false; }; "textAlign": { "alias": "textAlign"; "required": false; }; "placeHolder": { "alias": "placeHolder"; "required": false; }; "selectionOnFocus": { "alias": "selectionOnFocus"; "required": false; }; "textMode": { "alias": "textMode"; "required": false; }; "spinWrapAround": { "alias": "spinWrapAround"; "required": false; }; "isLimitedToListValues": { "alias": "isLimitedToListValues"; "required": false; }; "revertIfNotValid": { "alias": "revertIfNotValid"; "required": false; }; "preventSubmitOnEnter": { "alias": "preventSubmitOnEnter"; "required": false; }; "dropDownOrientation": { "alias": "dropDownOrientation"; "required": false; }; "maxLength": { "alias": "maxLength"; "required": false; }; "dropDownOnReadOnly": { "alias": "dropDownOnReadOnly"; "required": false; }; "toUpper": { "alias": "toUpper"; "required": false; }; "toLower": { "alias": "toLower"; "required": false; }; "locale": { "alias": "locale"; "required": false; }; "suppressNotifications": { "alias": "suppressNotifications"; "required": false; }; "regional": { "alias": "regional"; "required": false; }; "inputMask": { "alias": "inputMask"; "required": false; }; "dataMode": { "alias": "dataMode"; "required": false; }; "unfilledCharsPrompt": { "alias": "unfilledCharsPrompt"; "required": false; }; "padChar": { "alias": "padChar"; "required": false; }; "emptyChar": { "alias": "emptyChar"; "required": false; }; "minValue": { "alias": "minValue"; "required": false; }; "maxValue": { "alias": "maxValue"; "required": false; }; "dateDisplayFormat": { "alias": "dateDisplayFormat"; "required": false; }; "dateInputFormat": { "alias": "dateInputFormat"; "required": false; }; "spinDelta": { "alias": "spinDelta"; "required": false; }; "limitSpinToCurrentField": { "alias": "limitSpinToCurrentField"; "required": false; }; "enableUTCDates": { "alias": "enableUTCDates"; "required": false; }; "centuryThreshold": { "alias": "centuryThreshold"; "required": false; }; "yearShift": { "alias": "yearShift"; "required": false; }; "datepickerOptions": { "alias": "datepickerOptions"; "required": false; }; }, { "rendering": "rendering"; "rendered": "rendered"; "mousedown": "mousedown"; "mouseup": "mouseup"; "mousemove": "mousemove"; "mouseover": "mouseover"; "mouseout": "mouseout"; "blur": "blur"; "focus": "focus"; "keydown": "keydown"; "keypress": "keypress"; "keyup": "keyup"; "valueChanging": "valueChanging"; "valueChanged": "valueChanged"; "dropDownListOpening": "dropDownListOpening"; "dropDownListOpened": "dropDownListOpened"; "dropDownListClosing": "dropDownListClosing"; "dropDownListClosed": "dropDownListClosed"; "dropDownItemSelecting": "dropDownItemSelecting"; "dropDownItemSelected": "dropDownItemSelected"; "textChanged": "textChanged"; "itemSelected": "itemSelected"; }, never, ["*"], false, never>;
}
