/// <reference types="ignite-ui" />
import { IgEditorBase } from './igeditorbase';
import { IterableDiffers, ElementRef, KeyValueDiffers, ChangeDetectorRef, Renderer2 } from '@angular/core';
import { NgModel } from '@angular/forms';
import * as i0 from "@angular/core";
export declare class IgMaskEditorComponent extends IgEditorBase<IgMaskEditor> {
    model: NgModel;
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef, model: NgModel);
    /**
     * Gets/Sets mask editor value.
     *
     * @param newValue New mask editor value.
     */
    value(newValue?: string): string;
    dropDownContainer(): void;
    showDropDown(): void;
    hideDropDown(): void;
    dropDownButton(): void;
    spinUpButton(): void;
    spinDownButton(): void;
    dropDownVisible(): void;
    findListItemIndex(): void;
    selectedListIndex(): void;
    getSelectedListItem(): void;
    spinUp(): void;
    spinDown(): void;
    /**
     * Checks if the value in the editor is valid. Note: This function will not trigger automatic notifications.
     */
    isValid(): boolean;
    /**
     * Changes the all locales into the widget element to the language specified in [options.language](ui.igtexteditor#options:language)
     * Note that this method is for rare scenarios, see [language](ui.igtexteditor#options:language) or
     * [locale](ui.igtexteditor#options:locale) option setter
     */
    changeLocale(): void;
    /**
     * Gets the visible text in the editor.
     */
    displayValue(): string;
    /**
     * Returns a reference to the clear button UI element of the editor.
     */
    clearButton(): string;
    /**
     * Gets the selected text from the editor in edit mode. This can be done inside key event handlers, like keydown or keyup.
     * This method can be used only when the editor is focused.
     * If you invoke this method in display mode, when the editor input is blurred, the returned value will be an empty string.
     */
    getSelectedText(): string;
    /**
     * Gets the start index of the selected text in the editor.
     */
    getSelectionStart(): number;
    /**
     * Gets the end index of the selected text in the editor.
     */
    getSelectionEnd(): number;
    /**
     * Inserts the text at the location of the caret or over the current selection.
     * If the editor is focused the method will insert the text over the current selection.
     * If the editor is not focused the method will set the text as value of the editor.
     * Note: The method raises [textChanged](ui.igtexteditor#events:textChanged) event.
     *
     * @param value The string to be inserted.
     */
    insert(value: string): void;
    /**
     * Selects the text between start and end indices in the editor.
     * If the parameters are equal, then the method sets location of caret. The method has effect only when the editor has focus.
     *
     * @param start Start of the selection.
     * @param end End of the selection.
     */
    select(start: number, end: number): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgMaskEditorComponent, [null, null, null, null, null, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgMaskEditorComponent, "ig-mask-editor", never, { "widgetId": { "alias": "widgetId"; "required": false; }; "options": { "alias": "options"; "required": false; }; "changeDetectionInterval": { "alias": "changeDetectionInterval"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "create": { "alias": "create"; "required": false; }; "width": { "alias": "width"; "required": false; }; "height": { "alias": "height"; "required": false; }; "value": { "alias": "value"; "required": false; }; "tabIndex": { "alias": "tabIndex"; "required": false; }; "allowNullValue": { "alias": "allowNullValue"; "required": false; }; "nullValue": { "alias": "nullValue"; "required": false; }; "inputName": { "alias": "inputName"; "required": false; }; "readOnly": { "alias": "readOnly"; "required": false; }; "validatorOptions": { "alias": "validatorOptions"; "required": false; }; "buttonType": { "alias": "buttonType"; "required": false; }; "listItems": { "alias": "listItems"; "required": false; }; "listWidth": { "alias": "listWidth"; "required": false; }; "listItemHoverDuration": { "alias": "listItemHoverDuration"; "required": false; }; "dropDownAttachedToBody": { "alias": "dropDownAttachedToBody"; "required": false; }; "dropDownAnimationDuration": { "alias": "dropDownAnimationDuration"; "required": false; }; "visibleItemsCount": { "alias": "visibleItemsCount"; "required": false; }; "includeKeys": { "alias": "includeKeys"; "required": false; }; "excludeKeys": { "alias": "excludeKeys"; "required": false; }; "textAlign": { "alias": "textAlign"; "required": false; }; "placeHolder": { "alias": "placeHolder"; "required": false; }; "selectionOnFocus": { "alias": "selectionOnFocus"; "required": false; }; "textMode": { "alias": "textMode"; "required": false; }; "spinWrapAround": { "alias": "spinWrapAround"; "required": false; }; "isLimitedToListValues": { "alias": "isLimitedToListValues"; "required": false; }; "revertIfNotValid": { "alias": "revertIfNotValid"; "required": false; }; "preventSubmitOnEnter": { "alias": "preventSubmitOnEnter"; "required": false; }; "dropDownOrientation": { "alias": "dropDownOrientation"; "required": false; }; "maxLength": { "alias": "maxLength"; "required": false; }; "dropDownOnReadOnly": { "alias": "dropDownOnReadOnly"; "required": false; }; "toUpper": { "alias": "toUpper"; "required": false; }; "toLower": { "alias": "toLower"; "required": false; }; "locale": { "alias": "locale"; "required": false; }; "suppressNotifications": { "alias": "suppressNotifications"; "required": false; }; "regional": { "alias": "regional"; "required": false; }; "inputMask": { "alias": "inputMask"; "required": false; }; "dataMode": { "alias": "dataMode"; "required": false; }; "unfilledCharsPrompt": { "alias": "unfilledCharsPrompt"; "required": false; }; "padChar": { "alias": "padChar"; "required": false; }; "emptyChar": { "alias": "emptyChar"; "required": false; }; }, { "rendering": "rendering"; "rendered": "rendered"; "mousedown": "mousedown"; "mouseup": "mouseup"; "mousemove": "mousemove"; "mouseover": "mouseover"; "mouseout": "mouseout"; "blur": "blur"; "focus": "focus"; "keydown": "keydown"; "keypress": "keypress"; "keyup": "keyup"; "valueChanging": "valueChanging"; "valueChanged": "valueChanged"; "dropDownListOpening": "dropDownListOpening"; "dropDownListOpened": "dropDownListOpened"; "dropDownListClosing": "dropDownListClosing"; "dropDownListClosed": "dropDownListClosed"; "dropDownItemSelecting": "dropDownItemSelecting"; "dropDownItemSelected": "dropDownItemSelected"; "textChanged": "textChanged"; }, never, ["*"], false, never>;
}
