/// <reference types="ignite-ui" />
import { ElementRef, IterableDiffers, KeyValueDiffers, ChangeDetectorRef, Renderer2 } from '@angular/core';
import { IgEditorBase } from './igeditorbase';
import { NgModel } from '@angular/forms';
import * as i0 from "@angular/core";
export declare class IgTextEditorComponent extends IgEditorBase<IgTextEditor> {
    model: NgModel;
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef, model: NgModel);
    /**
     * Changes the all locales into the widget element to the language specified in [options.language](ui.igtexteditor#options:language)
     * Note that this method is for rare scenarios, see [language](ui.igtexteditor#options:language) or
     * [locale](ui.igtexteditor#options:locale) option setter
     */
    changeLocale(): void;
    /**
     * Gets the visible text in the editor.
     */
    displayValue(): string;
    /**
     * Gets reference to jquery object which is used as container of drop-down list.
     */
    dropDownContainer(): string;
    /**
     * Shows the drop down list.
     */
    showDropDown(): void;
    /**
     * Hides the drop down list.
     */
    hideDropDown(): void;
    /**
     * Returns a reference to the drop-down button UI element of the editor.
     */
    dropDownButton(): string;
    /**
     * Returns if the drop-down list is visible.
     */
    dropDownVisible(): boolean;
    /**
     * Returns a reference to the clear button UI element of the editor.
     */
    clearButton(): string;
    /**
     * Finds index of list item by text that matches with the search parameters.
     *
     * @param text The text to search for in the drop down list.
     * @param matchType The rule that is applied for searching the text.
     */
    findListItemIndex(text: string, matchType?: object): number;
    /**
     * Gets the index of the selected list item. Sets selected item by index.
     *
     * @param index The index of the item that needs to be selected.
     */
    selectedListIndex(index?: number): number;
    /**
     * Gets the selected list item.
     */
    getSelectedListItem(): string;
    /**
     * Gets the selected text from the editor in edit mode. This can be done inside key event handlers, like keydown or keyup.
     * This method can be used only when the editor is focused.
     * If you invoke this method in display mode, when the editor input is blurred, the returned value will be an empty string.
     */
    getSelectedText(): string;
    /**
     * Gets the start index of the selected text in the editor.
     */
    getSelectionStart(): number;
    /**
     * Gets the end index of the selected text in the editor.
     */
    getSelectionEnd(): number;
    /**
     * Inserts the text at the location of the caret or over the current selection.
     * If the editor is focused the method will insert the text over the current selection.
     * If the editor is not focused the method will set the text as value of the editor.
     * Note: The method raises [textChanged](ui.igtexteditor#events:textChanged) event.
     *
     * @param value The string to be inserted.
     */
    insert(value: string): void;
    /**
     * Selects the text between start and end indices in the editor.
     * If the parameters are equal, then the method sets location of caret. The method has effect only when the editor has focus.
     *
     * @param start Start of the selection.
     * @param end End of the selection.
     */
    select(start: number, end: number): void;
    /**
     * Selects the previous item from the drop-down list.
     */
    spinUp(): void;
    /**
     * Selects the next item from the drop-down list.
     */
    spinDown(): void;
    /**
     * Returns a reference to the spin up UI element of the editor.
     */
    spinUpButton(): string;
    /**
     * Returns a reference to the spin down UI element of the editor.
     */
    spinDownButton(): string;
    /**
     * Gets/Sets name attribute applied to the editor element.
     *
     * @param newValue The new input name.
     */
    inputName(newValue?: string): string;
    value(newValue: object): void;
    /**
     * Gets the input element of the editor.
     */
    field(): string;
    /**
     * Gets a reference to the jQuery element that wraps the editor.
     */
    editorContainer(): string;
    /**
     * Gets whether the editor has focus.
     */
    hasFocus(): boolean;
    /**
     * Sets focus to the editor after the specified delay.
     *
     * @param delay The delay before focusing the editor.
     */
    setFocus(delay?: number): void;
    /**
     * Hides the editor.
     */
    hide(): void;
    /**
     * Shows the editor.
     */
    show(): void;
    /**
     * Gets a reference to [igValidator](ui.igvalidator) used by the editor.
     */
    validator(): object;
    /**
     * Checks if the value in the editor is valid. Note: This function will not trigger automatic notifications.
     */
    isValid(): boolean;
    /**
     * Triggers validation for the editor. If validatorOptions are set will also call validate on the [igValidator](ui.igvalidator).
     */
    validate(): boolean;
    /**
     * Destroys the widget
     */
    destroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgTextEditorComponent, [null, null, null, null, null, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgTextEditorComponent, "ig-text-editor", never, { "widgetId": { "alias": "widgetId"; "required": false; }; "options": { "alias": "options"; "required": false; }; "changeDetectionInterval": { "alias": "changeDetectionInterval"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "create": { "alias": "create"; "required": false; }; "width": { "alias": "width"; "required": false; }; "height": { "alias": "height"; "required": false; }; "value": { "alias": "value"; "required": false; }; "tabIndex": { "alias": "tabIndex"; "required": false; }; "allowNullValue": { "alias": "allowNullValue"; "required": false; }; "nullValue": { "alias": "nullValue"; "required": false; }; "inputName": { "alias": "inputName"; "required": false; }; "readOnly": { "alias": "readOnly"; "required": false; }; "validatorOptions": { "alias": "validatorOptions"; "required": false; }; "buttonType": { "alias": "buttonType"; "required": false; }; "listItems": { "alias": "listItems"; "required": false; }; "listWidth": { "alias": "listWidth"; "required": false; }; "listItemHoverDuration": { "alias": "listItemHoverDuration"; "required": false; }; "dropDownAttachedToBody": { "alias": "dropDownAttachedToBody"; "required": false; }; "dropDownAnimationDuration": { "alias": "dropDownAnimationDuration"; "required": false; }; "visibleItemsCount": { "alias": "visibleItemsCount"; "required": false; }; "includeKeys": { "alias": "includeKeys"; "required": false; }; "excludeKeys": { "alias": "excludeKeys"; "required": false; }; "textAlign": { "alias": "textAlign"; "required": false; }; "placeHolder": { "alias": "placeHolder"; "required": false; }; "selectionOnFocus": { "alias": "selectionOnFocus"; "required": false; }; "textMode": { "alias": "textMode"; "required": false; }; "spinWrapAround": { "alias": "spinWrapAround"; "required": false; }; "isLimitedToListValues": { "alias": "isLimitedToListValues"; "required": false; }; "revertIfNotValid": { "alias": "revertIfNotValid"; "required": false; }; "preventSubmitOnEnter": { "alias": "preventSubmitOnEnter"; "required": false; }; "dropDownOrientation": { "alias": "dropDownOrientation"; "required": false; }; "maxLength": { "alias": "maxLength"; "required": false; }; "dropDownOnReadOnly": { "alias": "dropDownOnReadOnly"; "required": false; }; "toUpper": { "alias": "toUpper"; "required": false; }; "toLower": { "alias": "toLower"; "required": false; }; "locale": { "alias": "locale"; "required": false; }; "suppressNotifications": { "alias": "suppressNotifications"; "required": false; }; }, { "rendering": "rendering"; "rendered": "rendered"; "mousedown": "mousedown"; "mouseup": "mouseup"; "mousemove": "mousemove"; "mouseover": "mouseover"; "mouseout": "mouseout"; "blur": "blur"; "focus": "focus"; "keydown": "keydown"; "keypress": "keypress"; "keyup": "keyup"; "valueChanging": "valueChanging"; "valueChanged": "valueChanged"; "dropDownListOpening": "dropDownListOpening"; "dropDownListOpened": "dropDownListOpened"; "dropDownListClosing": "dropDownListClosing"; "dropDownListClosed": "dropDownListClosed"; "dropDownItemSelecting": "dropDownItemSelecting"; "dropDownItemSelected": "dropDownItemSelected"; "textChanged": "textChanged"; }, never, ["*"], false, never>;
}
