/// <reference types="ignite-ui" />
import { ElementRef, IterableDiffers, KeyValueDiffers, ChangeDetectorRef, Renderer2 } from '@angular/core';
import { IgEditorBase } from './igeditorbase';
import { NgModel } from '@angular/forms';
import * as i0 from "@angular/core";
export declare class IgTimePickerComponent extends IgEditorBase<IgTimePicker> {
    model: NgModel;
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef, model: NgModel);
    /**
     * Gets the selected list item.
     */
    getSelectedListItem(): string;
    /**
     * Returns the visibility state of the calendar.
     */
    dropDownVisible(): boolean;
    /**
     * Returns a reference to the drop-down button UI element of the editor.
     */
    dropDownButton(): string;
    /**
     * Gets reference to jquery object which is used as container of drop-down list.
     */
    dropDownContainer(): string;
    /**
     * Finds index of list item by text that matches with the search parameters.
     *
     * @param text The text to search for in the drop down list.
     * @param matchType The rule that is applied for searching the text.
     */
    findListItemIndex(text: string, matchType?: object): number;
    /**
     * Gets the index of the selected list item. Sets selected item by index.
     *
     * @param index The index of the item that needs to be selected.
     */
    selectedListIndex(index?: number): number;
    value(newValue: object): void;
    selectDate(): void;
    /**
     * Changes the the regional settings of widget element to the language specified in [options.regional](ui.igdateeditor#options:regional)
     * Note that this method is for rare scenarios, use [regional](ui.igdateeditor#options:regional) option setter
     */
    changeRegional(): void;
    /**
     * Gets selected date as a date object. This method can be used when dataMode is set as either displayModeText or editModeText.
     * In such cases the value() method will not return date object and getSelectedDate() can be used to replace that functionality.
     */
    getSelectedDate(): Date;
    /**
     * Increases the date or time period, depending on the current cursor position.
     *
     * @param delta The increase delta.
     */
    spinUp(delta?: number): void;
    /**
     * Decreases the date or time period, depending on the current cursor position.
     *
     * @param delta The decrease delta.
     */
    spinDown(delta?: number): void;
    /**
     * Returns a reference to the spin up UI element of the editor.
     */
    spinUpButton(): string;
    /**
     * Returns a reference to the spin down UI element of the editor.
     */
    spinDownButton(): string;
    /**
     * Checks if the value in the editor is valid. Note: This function will not trigger automatic notifications.
     */
    isValid(): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgTimePickerComponent, [null, null, null, null, null, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgTimePickerComponent, "ig-time-picker", never, { "widgetId": { "alias": "widgetId"; "required": false; }; "options": { "alias": "options"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "create": { "alias": "create"; "required": false; }; "locale": { "alias": "locale"; "required": false; }; "language": { "alias": "language"; "required": false; }; "regional": { "alias": "regional"; "required": false; }; "width": { "alias": "width"; "required": false; }; "height": { "alias": "height"; "required": false; }; "value": { "alias": "value"; "required": false; }; "tabIndex": { "alias": "tabIndex"; "required": false; }; "allowNullValue": { "alias": "allowNullValue"; "required": false; }; "nullValue": { "alias": "nullValue"; "required": false; }; "inputName": { "alias": "inputName"; "required": false; }; "readOnly": { "alias": "readOnly"; "required": false; }; "validatorOptions": { "alias": "validatorOptions"; "required": false; }; "buttonType": { "alias": "buttonType"; "required": false; }; "listItems": { "alias": "listItems"; "required": false; }; "listWidth": { "alias": "listWidth"; "required": false; }; "listItemHoverDuration": { "alias": "listItemHoverDuration"; "required": false; }; "dropDownAttachedToBody": { "alias": "dropDownAttachedToBody"; "required": false; }; "dropDownAnimationDuration": { "alias": "dropDownAnimationDuration"; "required": false; }; "visibleItemsCount": { "alias": "visibleItemsCount"; "required": false; }; "includeKeys": { "alias": "includeKeys"; "required": false; }; "excludeKeys": { "alias": "excludeKeys"; "required": false; }; "textAlign": { "alias": "textAlign"; "required": false; }; "placeHolder": { "alias": "placeHolder"; "required": false; }; "selectionOnFocus": { "alias": "selectionOnFocus"; "required": false; }; "textMode": { "alias": "textMode"; "required": false; }; "spinWrapAround": { "alias": "spinWrapAround"; "required": false; }; "isLimitedToListValues": { "alias": "isLimitedToListValues"; "required": false; }; "revertIfNotValid": { "alias": "revertIfNotValid"; "required": false; }; "preventSubmitOnEnter": { "alias": "preventSubmitOnEnter"; "required": false; }; "dropDownOrientation": { "alias": "dropDownOrientation"; "required": false; }; "maxLength": { "alias": "maxLength"; "required": false; }; "dropDownOnReadOnly": { "alias": "dropDownOnReadOnly"; "required": false; }; "toUpper": { "alias": "toUpper"; "required": false; }; "toLower": { "alias": "toLower"; "required": false; }; "suppressNotifications": { "alias": "suppressNotifications"; "required": false; }; "suppressKeyboard": { "alias": "suppressKeyboard"; "required": false; }; "inputMask": { "alias": "inputMask"; "required": false; }; "dataMode": { "alias": "dataMode"; "required": false; }; "unfilledCharsPrompt": { "alias": "unfilledCharsPrompt"; "required": false; }; "padChar": { "alias": "padChar"; "required": false; }; "emptyChar": { "alias": "emptyChar"; "required": false; }; "minValue": { "alias": "minValue"; "required": false; }; "maxValue": { "alias": "maxValue"; "required": false; }; "dateDisplayFormat": { "alias": "dateDisplayFormat"; "required": false; }; "dateInputFormat": { "alias": "dateInputFormat"; "required": false; }; "displayTimeOffset": { "alias": "displayTimeOffset"; "required": false; }; "spinDelta": { "alias": "spinDelta"; "required": false; }; "limitSpinToCurrentField": { "alias": "limitSpinToCurrentField"; "required": false; }; "enableUTCDates": { "alias": "enableUTCDates"; "required": false; }; "centuryThreshold": { "alias": "centuryThreshold"; "required": false; }; "yearShift": { "alias": "yearShift"; "required": false; }; "itemsDelta": { "alias": "itemsDelta"; "required": false; }; "timeInputFormat": { "alias": "timeInputFormat"; "required": false; }; "timeDisplayFormat": { "alias": "timeDisplayFormat"; "required": false; }; }, { "rendering": "rendering"; "rendered": "rendered"; "mousedown": "mousedown"; "mouseup": "mouseup"; "mousemove": "mousemove"; "mouseover": "mouseover"; "mouseout": "mouseout"; "blur": "blur"; "focus": "focus"; "keydown": "keydown"; "keypress": "keypress"; "keyup": "keyup"; "valueChanging": "valueChanging"; "valueChanged": "valueChanged"; "dropDownListOpening": "dropDownListOpening"; "dropDownListOpened": "dropDownListOpened"; "dropDownListClosing": "dropDownListClosing"; "dropDownListClosed": "dropDownListClosed"; "dropDownItemSelecting": "dropDownItemSelecting"; "dropDownItemSelected": "dropDownItemSelected"; "textChanged": "textChanged"; }, never, ["*"], false, never>;
}
