/// <reference types="ignite-ui" />
import { ElementRef } from '@angular/core';
import { Feature } from '../feature';
import * as i0 from "@angular/core";
export declare class IgGridColumnFixingFeature extends Feature<IgGridColumnFixing> {
    constructor(el: ElementRef);
    /**
     * Unfixes a column by specified column identifier - column key or column index.
     *
     * @param colIdentifier    An identifier of the column to be unfixed - column index or column key.
     * @param target    Key of the column where the unfixed column should move to.
     * @param after    Specifies where the unfixed column should be rendered after or before the target column.
     * This parameter is disregarded if there is no target column specified.
     */
    unfixColumn(colIdentifier: object, target?: string, after?: boolean): object;
    /**
     * Checks whether the heights of fixed and unfixed tables are equal - if not sync them. Similar check is made for heights of table rows.
     */
    checkAndSyncHeights(): void;
    /**
     * If the 'check' argument is set to true, checks whether the heights of fixed and unfixed tables are equal, if not sync them.
     * Similar check is made for heights of table rows.
     * If the clearRowsHeights argument is set to true, clears rows heights before syncing them.
     *
     * @param check    If set to true, checks whether the heights of fixed and unfixed tables are equal, if not sync them.
     * If this argument is set to false sync is performed regardless of the current heights.
     * @param clearRowsHeights    Clears row heigths for all visible rows.
     */
    syncHeights(check?: boolean, clearRowsHeights?: boolean): void;
    /**
     * Returns whether the column with the specified key is a column group header
     *  when the [multi-column headers](http://www.igniteui.com/help/iggrid-multicolumnheaders-landingpage) feature is used.
     *
     * @param colKey    The key of the column to perform the check for.
     */
    isGroupHeader(colKey: string): boolean;
    /**
     * Checks whether column fixing is allowed for the specified columns.
     * It should not be allowed if there is only one visible column in the unfixed area.
     *
     * @param columns    Array of columns and/or column identifiers - could be column indexes, column keys, column object or mixed.
     */
    checkFixingAllowed(columns: any[]): boolean;
    /**
     * Checks whether unfixing is allowed for the specified columns.
     * It should not be allowed if there is only one visible column in the fixed area.
     *
     * @param columns    Array of columns and/or column identifiers - could be column indexes, column keys, column object or mixed.
     */
    checkUnfixingAllowed(columns: any[]): boolean;
    /**
     * Fixes non-data columns (such as the row numbering column of row selectors) if any and if
     * [fixingDirection](ui.iggridcolumnfixing#options:fixingDirection) is left. Does nothing if the non-data columns are already fixed.
     */
    fixNonDataColumns(): void;
    /**
     * This function is deprecated - use function fixNonDataColumns.
     */
    fixDataSkippedColumns(): void;
    /**
     * Unfixes non-data columns (such as the row numbering column of row selectors) if any and if
     * [fixingDirection](ui.iggridcolumnfixing#options:fixingDirection) is left. Does nothing if the non-data columns are already fixed.
     */
    unfixNonDataColumns(): void;
    /**
     * This function is deprecated - use function unfixNonDataColumns.
     */
    unfixDataSkippedColumns(): void;
    /**
     * Unfixes all fixed columns.
     */
    unfixAllColumns(): void;
    /**
     * Syncs rows heights between two collections of rows.
     *
     * @param $trs    An array of rows of the first(fixed/unfixed) container.
     * @param $anotherRows    An array of rows of the second(fixed/unfixed) container.
     */
    syncRowsHeights($trs: any[], $anotherRows: any[]): void;
    /**
     * Calculates widths of the fixed columns.
     *
     * @param fCols    Array of grid columns. If not set then the total width of the fixed columns are returned.
     * @param excludeNonDataColumns If set to true do not calculate the width of non-data fixed columns
     *                              (like the row selector row numbering column).
     * @param includeHidden    If set to true calculates width of the hidden fixed columns (their initial width before hiding).
     */
    getWidthOfFixedColumns(fCols?: any[], excludeNonDataColumns?: boolean, includeHidden?: boolean): number;
    /**
     * Destroys the column fixing widget
     */
    destroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgGridColumnFixingFeature, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<IgGridColumnFixingFeature, "column-fixing", never, { "disabled": { "alias": "disabled"; "required": false; }; "create": { "alias": "create"; "required": false; }; "headerFixButtonText": { "alias": "headerFixButtonText"; "required": false; }; "headerUnfixButtonText": { "alias": "headerUnfixButtonText"; "required": false; }; "showFixButtons": { "alias": "showFixButtons"; "required": false; }; "syncRowHeights": { "alias": "syncRowHeights"; "required": false; }; "scrollDelta": { "alias": "scrollDelta"; "required": false; }; "fixingDirection": { "alias": "fixingDirection"; "required": false; }; "columnSettings": { "alias": "columnSettings"; "required": false; }; "featureChooserTextFixedColumn": { "alias": "featureChooserTextFixedColumn"; "required": false; }; "featureChooserTextUnfixedColumn": { "alias": "featureChooserTextUnfixedColumn"; "required": false; }; "minimalVisibleAreaWidth": { "alias": "minimalVisibleAreaWidth"; "required": false; }; "fixNondataColumns": { "alias": "fixNondataColumns"; "required": false; }; "populateDataRowsAttributes": { "alias": "populateDataRowsAttributes"; "required": false; }; }, { "columnFixing": "columnFixing"; "columnFixed": "columnFixed"; "columnUnfixing": "columnUnfixing"; "columnUnfixed": "columnUnfixed"; "columnFixingRefused": "columnFixingRefused"; "columnUnfixingRefused": "columnUnfixingRefused"; }, never, never, false, never>;
}
