/// <reference types="ignite-ui" />
import { ElementRef } from '@angular/core';
import { Feature } from '../feature';
import * as i0 from "@angular/core";
export declare class IgGridColumnMovingFeature extends Feature<IgGridColumnMoving> {
    constructor(el: ElementRef);
    /**
     * Restoring overwritten functions
     */
    destroy(): void;
    /**
     * Moves a visible column at a specified place, in front or behind a target column or at a target index
     * Note: This method is asynchronous which means that it returns immediately and any subsequent code will execute in parallel.
     * This may lead to runtime errors. To avoid them put the subsequent code in the callback parameter provided by the method.
     *
     * @param column    An identifier of the column to be moved.
     * It can be a key, a Multi-Column Header identificator, or an index in a number format.
     * The latter is not supported when the grid contains multi-column headers.
     * @param target An identifier of a column where the moved column should move to or an index at which the moved column should
     * be moved to. In the case of a column identifier the column will be moved after it by default.
     * @param after    Specifies whether the column moved should be moved after or before the target column.
     * @param inDom    Specifies whether the column moving will be enacted through DOM manipulation or through rerendering of the grid.
     * @param callback    Specifies a custom function to be called when the column is moved.
     */
    moveColumn(column: object, target: object, after?: boolean, inDom?: boolean, callback?: () => void): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgGridColumnMovingFeature, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<IgGridColumnMovingFeature, "column-moving", never, { "disabled": { "alias": "disabled"; "required": false; }; "create": { "alias": "create"; "required": false; }; "columnSettings": { "alias": "columnSettings"; "required": false; }; "mode": { "alias": "mode"; "required": false; }; "moveType": { "alias": "moveType"; "required": false; }; "addMovingDropdown": { "alias": "addMovingDropdown"; "required": false; }; "movingDialogWidth": { "alias": "movingDialogWidth"; "required": false; }; "movingDialogHeight": { "alias": "movingDialogHeight"; "required": false; }; "movingDialogAnimationDuration": { "alias": "movingDialogAnimationDuration"; "required": false; }; "movingAcceptanceTolerance": { "alias": "movingAcceptanceTolerance"; "required": false; }; "movingScrollTolerance": { "alias": "movingScrollTolerance"; "required": false; }; "scrollSpeedMultiplier": { "alias": "scrollSpeedMultiplier"; "required": false; }; "scrollDelta": { "alias": "scrollDelta"; "required": false; }; "hideHeaderContentsDuringDrag": { "alias": "hideHeaderContentsDuringDrag"; "required": false; }; "dragHelperOpacity": { "alias": "dragHelperOpacity"; "required": false; }; "movingDialogCaptionButtonDesc": { "alias": "movingDialogCaptionButtonDesc"; "required": false; }; "movingDialogCaptionButtonAsc": { "alias": "movingDialogCaptionButtonAsc"; "required": false; }; "movingDialogCaptionText": { "alias": "movingDialogCaptionText"; "required": false; }; "movingDialogDisplayText": { "alias": "movingDialogDisplayText"; "required": false; }; "movingDialogDropTooltipText": { "alias": "movingDialogDropTooltipText"; "required": false; }; "movingDialogDropTooltipMarkup": { "alias": "movingDialogDropTooltipMarkup"; "required": false; }; "dropDownMoveLeftText": { "alias": "dropDownMoveLeftText"; "required": false; }; "dropDownMoveRightText": { "alias": "dropDownMoveRightText"; "required": false; }; "dropDownMoveFirstText": { "alias": "dropDownMoveFirstText"; "required": false; }; "dropDownMoveLastText": { "alias": "dropDownMoveLastText"; "required": false; }; "movingToolTipMove": { "alias": "movingToolTipMove"; "required": false; }; "featureChooserSubmenuText": { "alias": "featureChooserSubmenuText"; "required": false; }; "columnMovingDialogContainment": { "alias": "columnMovingDialogContainment"; "required": false; }; "dialogWidget": { "alias": "dialogWidget"; "required": false; }; "inherit": { "alias": "inherit"; "required": false; }; }, { "columnDragStart": "columnDragStart"; "columnDragEnd": "columnDragEnd"; "columnDragCanceled": "columnDragCanceled"; "columnMoving": "columnMoving"; "columnMoved": "columnMoved"; "movingDialogOpening": "movingDialogOpening"; "movingDialogOpened": "movingDialogOpened"; "movingDialogDragged": "movingDialogDragged"; "movingDialogClosing": "movingDialogClosing"; "movingDialogClosed": "movingDialogClosed"; "movingDialogContentsRendering": "movingDialogContentsRendering"; "movingDialogContentsRendered": "movingDialogContentsRendered"; "movingDialogMoveUpButtonPressed": "movingDialogMoveUpButtonPressed"; "movingDialogMoveDownButtonPressed": "movingDialogMoveDownButtonPressed"; "movingDialogDragColumnMoving": "movingDialogDragColumnMoving"; "movingDialogDragColumnMoved": "movingDialogDragColumnMoved"; }, never, never, false, never>;
}
