/// <reference types="ignite-ui" />
import { ElementRef } from '@angular/core';
import { Feature } from '../feature';
import * as i0 from "@angular/core";
export declare class IgGridSortingFeature extends Feature<IgGridSorting> {
    constructor(el: ElementRef);
    /**
     * Sorts the data in a grid column  and updates the UI.
     *
     * @param index     Column key (string) or index (number) - for multi-row grid only column key can be used.
     * Specifies the column which we want to sort. If the mode is multiple, previous sorting states are not cleared.
     * @param direction     Specifies sorting direction (ascending or descending)
     * @param header header
     */
    sortColumn(index: object, direction: object, header: object): void;
    /**
     * Sorts the data in grid columns and updates the UI.
     */
    sortMultiple(): void;
    /**
     * Removes current sorting(for all sorted columns) and updates the UI.
     */
    clearSorting(): void;
    /**
     * Removes sorting for the grid column with the specified columnKey/columnIndex and updates the UI.
     *
     * @param index     Column key (string) or index (number) - for multi-row grid only column key can be used.
     * Specifies the column for which we want to remove sorting. If the mode is multiple, previous sorting states are not cleared.
     * @param header    header
     */
    unsortColumn(index: object, header: object): void;
    /**
     * Destroys the sorting feature. Unbinds events, removes added sorting elements, etc.
     */
    destroy(): void;
    /**
     * Opens the multiple sorting dialog.
     */
    openMultipleSortingDialog(): void;
    /**
     * Closes the multiple sorting dialog.
     */
    closeMultipleSortingDialog(): void;
    /**
     * Renders content of multiple sorting dialog - sorted and unsorted columns.
     *
     * @param isToCallEvents - if specified client events should be fired
     */
    renderMultipleSortingDialogContent(isToCallEvents: object): void;
    /**
     * Remove clear button for multiple sorting dialog
     */
    removeDialogClearButton(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgGridSortingFeature, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<IgGridSortingFeature, "sorting", never, { "disabled": { "alias": "disabled"; "required": false; }; "create": { "alias": "create"; "required": false; }; "type": { "alias": "type"; "required": false; }; "caseSensitive": { "alias": "caseSensitive"; "required": false; }; "applySortedColumnCss": { "alias": "applySortedColumnCss"; "required": false; }; "sortUrlKey": { "alias": "sortUrlKey"; "required": false; }; "sortUrlKeyAscValue": { "alias": "sortUrlKeyAscValue"; "required": false; }; "sortUrlKeyDescValue": { "alias": "sortUrlKeyDescValue"; "required": false; }; "mode": { "alias": "mode"; "required": false; }; "customSortFunction": { "alias": "customSortFunction"; "required": false; }; "firstSortDirection": { "alias": "firstSortDirection"; "required": false; }; "sortedColumnTooltip": { "alias": "sortedColumnTooltip"; "required": false; }; "modalDialogSortOnClick": { "alias": "modalDialogSortOnClick"; "required": false; }; "modalDialogSortByButtonText": { "alias": "modalDialogSortByButtonText"; "required": false; }; "modalDialogResetButtonLabel": { "alias": "modalDialogResetButtonLabel"; "required": false; }; "modalDialogCaptionButtonDesc": { "alias": "modalDialogCaptionButtonDesc"; "required": false; }; "modalDialogCaptionButtonAsc": { "alias": "modalDialogCaptionButtonAsc"; "required": false; }; "modalDialogCaptionButtonUnsort": { "alias": "modalDialogCaptionButtonUnsort"; "required": false; }; "modalDialogWidth": { "alias": "modalDialogWidth"; "required": false; }; "modalDialogHeight": { "alias": "modalDialogHeight"; "required": false; }; "modalDialogAnimationDuration": { "alias": "modalDialogAnimationDuration"; "required": false; }; "featureChooserText": { "alias": "featureChooserText"; "required": false; }; "unsortedColumnTooltip": { "alias": "unsortedColumnTooltip"; "required": false; }; "columnSettings": { "alias": "columnSettings"; "required": false; }; "modalDialogCaptionText": { "alias": "modalDialogCaptionText"; "required": false; }; "modalDialogButtonApplyText": { "alias": "modalDialogButtonApplyText"; "required": false; }; "modalDialogButtonCancelText": { "alias": "modalDialogButtonCancelText"; "required": false; }; "featureChooserSortAsc": { "alias": "featureChooserSortAsc"; "required": false; }; "featureChooserSortDesc": { "alias": "featureChooserSortDesc"; "required": false; }; "persist": { "alias": "persist"; "required": false; }; "sortingDialogContainment": { "alias": "sortingDialogContainment"; "required": false; }; "dialogWidget": { "alias": "dialogWidget"; "required": false; }; "inherit": { "alias": "inherit"; "required": false; }; }, { "columnSorting": "columnSorting"; "columnSorted": "columnSorted"; "modalDialogOpening": "modalDialogOpening"; "modalDialogOpened": "modalDialogOpened"; "modalDialogMoving": "modalDialogMoving"; "modalDialogClosing": "modalDialogClosing"; "modalDialogClosed": "modalDialogClosed"; "modalDialogContentsRendering": "modalDialogContentsRendering"; "modalDialogContentsRendered": "modalDialogContentsRendered"; "modalDialogSortingChanged": "modalDialogSortingChanged"; "modalDialogButtonUnsortClick": "modalDialogButtonUnsortClick"; "modalDialogSortClick": "modalDialogSortClick"; "modalDialogButtonApplyClick": "modalDialogButtonApplyClick"; "modalDialogButtonResetClick": "modalDialogButtonResetClick"; }, never, never, false, never>;
}
