/// <reference types="ignite-ui" />
import { ElementRef } from '@angular/core';
import { Feature } from '../feature';
import * as i0 from "@angular/core";
export declare class IgGridUpdatingFeature extends Feature<IgGridUpdating> {
    constructor(el: ElementRef);
    /**
     * Sets a cell value for the specified cell. It also creates a transaction and updates the UI.
     * 			If the specified cell is currently in edit mode, the function will set the desired value in the cell's editor instead.
     *
     * @param rowId    The primary key of the row the cell is a child of.
     * @param colKey    The column key of the cell.
     * @param value    The new value for the cell.
     */
    setCellValue(rowId: object, colKey: string, value: object): void;
    /**
     * Sets values for specified cells in a row. It also creates a transaction and updates the UI.
     * 			If the specified row is currently in edit mode, the function will set the desired values in the row's editors instead.
     *
     * @param rowId    The primary key of the row to update.
     * @param values    Pairs of values in the format { column1Key: value1, column2Key: value2, ... } .
     */
    updateRow(rowId: any, values: object): void;
    /**
     * Adds a new row to the grid. It also creates a transaction and updates the UI.
     *
     * @param values    Pairs of values in the format { column1Key: value1, column2Key: value2, ... } .
     */
    addRow(values: object): void;
    /**
     * Deletes a row from the grid. It also creates a transaction and updates the UI.
     *
     * @param rowId    The primary key of the row to delete.
     */
    deleteRow(rowId: any): void;
    /**
     * Starts editing for the row or cell specified (depending on the [editMode](ui.iggridupdating#options:editMode)).
     *
     * @param rowId    The row id.
     * @param column    The column key or index.
     * @param raiseEvents    Specifies whether or not updating events should be raised for this operation.
     */
    startEdit(rowId: object, column: object, raiseEvents?: boolean): boolean;
    /**
     * Starts editing for adding a new row.
     *
     * @param raiseEvents    Specifies whether or not updating events should be raised for this operation.
     */
    startAddRowEdit(raiseEvents?: boolean): boolean;
    /**
     * Ends the currently active edit mode.
     *
     * @param update    Specifies if the edit process should accept the current changes. Default is 'false'.
     * @param raiseEvents    Specifies whether or not updating events should be raised for this operation.
     */
    endEdit(update?: boolean, raiseEvents?: boolean): boolean;
    /**
     * Finds and returns the key of the first column the editor for which has invalid value.
     */
    findInvalid(): string;
    /**
     * Checks if the grid is in edit mode.
     */
    isEditing(): boolean;
    /**
     * Gets the editor for a column by the column key. That method can be used only after the editor has been created.
     *
     * @param key    The key of the column.
     */
    editorForKey(key: string): object;
    /**
     * Gets the editor for a column by the cell it resides in. If allowed the function can create the editor if it has not been created yet.
     *
     * @param cell    Reference to the jQuery-wrapped TD object of the grid that the editor belongs to.
     * @param create    Requests to create the editor if it has not been created yet.
     */
    editorForCell(cell: string, create?: boolean): object;
    /**
     * Destroys igGridUpdating.
     */
    destroy(): object;
    /**
     * Shows the delete button for specific row.
     *
     * @param row    A jQuery object of the targeted row.
     */
    showDeleteButtonFor(row: object): void;
    /**
     * Hides the delete button.
     */
    hideDeleteButton(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgGridUpdatingFeature, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<IgGridUpdatingFeature, "updating", never, { "disabled": { "alias": "disabled"; "required": false; }; "create": { "alias": "create"; "required": false; }; "columnSettings": { "alias": "columnSettings"; "required": false; }; "editMode": { "alias": "editMode"; "required": false; }; "enableDeleteRow": { "alias": "enableDeleteRow"; "required": false; }; "enableAddRow": { "alias": "enableAddRow"; "required": false; }; "validation": { "alias": "validation"; "required": false; }; "doneLabel": { "alias": "doneLabel"; "required": false; }; "doneTooltip": { "alias": "doneTooltip"; "required": false; }; "cancelLabel": { "alias": "cancelLabel"; "required": false; }; "cancelTooltip": { "alias": "cancelTooltip"; "required": false; }; "addRowLabel": { "alias": "addRowLabel"; "required": false; }; "addRowTooltip": { "alias": "addRowTooltip"; "required": false; }; "deleteRowLabel": { "alias": "deleteRowLabel"; "required": false; }; "deleteRowTooltip": { "alias": "deleteRowTooltip"; "required": false; }; "showDoneCancelButtons": { "alias": "showDoneCancelButtons"; "required": false; }; "enableDataDirtyException": { "alias": "enableDataDirtyException"; "required": false; }; "startEditTriggers": { "alias": "startEditTriggers"; "required": false; }; "horizontalMoveOnEnter": { "alias": "horizontalMoveOnEnter"; "required": false; }; "excelNavigationMode": { "alias": "excelNavigationMode"; "required": false; }; "saveChangesSuccessHandler": { "alias": "saveChangesSuccessHandler"; "required": false; }; "saveChangesErrorHandler": { "alias": "saveChangesErrorHandler"; "required": false; }; "swipeDistance": { "alias": "swipeDistance"; "required": false; }; "wrapAround": { "alias": "wrapAround"; "required": false; }; "rowEditDialogOptions": { "alias": "rowEditDialogOptions"; "required": false; }; "dialogWidget": { "alias": "dialogWidget"; "required": false; }; "inherit": { "alias": "inherit"; "required": false; }; }, { "editRowStarting": "editRowStarting"; "editRowStarted": "editRowStarted"; "editRowEnding": "editRowEnding"; "editRowEnded": "editRowEnded"; "editCellStarting": "editCellStarting"; "editCellStarted": "editCellStarted"; "editCellEnding": "editCellEnding"; "editCellEnded": "editCellEnded"; "rowAdding": "rowAdding"; "rowAdded": "rowAdded"; "rowDeleting": "rowDeleting"; "rowDeleted": "rowDeleted"; "dataDirty": "dataDirty"; "generatePrimaryKeyValue": "generatePrimaryKeyValue"; "rowEditDialogBeforeOpen": "rowEditDialogBeforeOpen"; "rowEditDialogAfterOpen": "rowEditDialogAfterOpen"; "rowEditDialogBeforeClose": "rowEditDialogBeforeClose"; "rowEditDialogAfterClose": "rowEditDialogAfterClose"; "rowEditDialogContentsRendered": "rowEditDialogContentsRendered"; }, never, never, false, never>;
}
