/// <reference types="ignite-ui" />
import { IterableDiffers, KeyValueDiffers, ChangeDetectorRef, ElementRef, Renderer2 } from '@angular/core';
import { IgGridBase } from '../iggrid/iggridbase';
import * as i0 from "@angular/core";
export declare class IgHierarchicalGridComponent extends IgGridBase<IgHierarchicalGrid> {
    childrenDataProperty: string;
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef);
    deleteRow(id: any): void;
    updateRow(rec: any, currValue: any, key: any): void;
    markForCheck(): void;
    /**
     * Data binds the hierarchical grid. No child grids will be created or rendered by default, unless there is initialExpandDepth >= 0 set.
     */
    dataBind(): void;
    /**
     * Returns the element of the root grid (igGrid)
     */
    root(): object;
    /**
     * Returns the widget object of the root grid (igGrid)
     */
    rootWidget(): object;
    /**
     * Returns a flat list of all child grid elements (recursive)
     */
    allChildren(): object;
    /**
     * Expands or collapses (toggles) a parent row
     * Note: This method is asynchronous which means that it returns immediately and any subsequent code will execute in parallel.
     * This may lead to runtime errors. To avoid them put the subsequent code in the callback parameter provided by the method.
     *
     * @param element     accepts a dom element, or a jquery wrapped dom element that should be a TR and should specify a parent row
     * @param callback     Specifies a custom function to be called when parent row is toggled(optional).
     * Takes 2 arguments - first is hierarchical grid object, second is the row element that was toggled
     */
    toggle(element: Element, callback?: () => void): void;
    /**
     * Expands (toggles) a parent row
     * Note: This method is asynchronous which means that it returns immediately and any subsequent code will execute in parallel.
     * This may lead to runtime errors. To avoid them put the subsequent code in the callback parameter provided by the method.
     *
     * @param id     accepts a dom element, or a jquery wrapped dom element that should be a TR and should specify a parent row
     * @param callback     Specifies a custom function to be called when parent row is expanded(optional).
     * Takes 2 arguments first is hierarchical grid object, second is the row element that was expanded
     */
    expand(id: Element, callback?: () => void): void;
    /**
     * Collapses a parent row
     * Note: This method is asynchronous which means that it returns immediately and any subsequent code will execute in parallel.
     * This may lead to runtime errors. To avoid them put the subsequent code in the callback parameter provided by the method.
     *
     * @param id accepts a dom element, or a jquery wrapped dom element that should be a TR and should specify a parent row
     * @param callback Specifies a custom function to be called when parent row is expanded(optional).
     * Takes 2 arguments - first is hierarchical grid object, second is the row element that was collapsed
     */
    collapse(id: Element, callback?: () => void): void;
    /**
     * Checks if a parent row is currently collapsed
     *
     * @param element     accepts a dom element, or a jquery wrapped dom element that should be a TR and should specify a parent row
     */
    collapsed(element: Element): boolean;
    /**
     * Checks if a parent row is populated with data
     *
     * @param element     accepts a dom element, or a jquery wrapped dom element that should be a TR and should specify a parent row
     */
    populated(element: Element): boolean;
    /**
     * Commits pending transactions to the client data source for main and all child grids.
     */
    commit(): void;
    /**
     * Clears the transaction log (delegates to igDataSource). Note that this does not update the UI.
     * In case the UI must be updated, set the second parameter "updateUI" to true, which will trigger a call to dataBind()
     * to re-render the contents.
     *
     * @param rebind     Whether to perform a rebind.
     */
    rollback(rebind?: boolean): void;
    /**
     * Posts to the settings.updateUrl using $.ajax, by serializing the changes as url params
     *
     * @param success    Specifies a custom function to be called when AJAX request to the updateUrl option succeeds(optional)
     * @param error    Specifies a custom function to be called when AJAX request to the updateUrl option fails(optional)
     */
    saveChanges(success: () => void, error: () => void): void;
    /**
     * Destroys the hierarchical grid by recursively destroying all child grids
     */
    destroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgHierarchicalGridComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgHierarchicalGridComponent, "ig-hierarchical-grid", never, { "widgetId": { "alias": "widgetId"; "required": false; }; "options": { "alias": "options"; "required": false; }; "changeDetectionInterval": { "alias": "changeDetectionInterval"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "create": { "alias": "create"; "required": false; }; "initialDataBindDepth": { "alias": "initialDataBindDepth"; "required": false; }; "initialExpandDepth": { "alias": "initialExpandDepth"; "required": false; }; "odata": { "alias": "odata"; "required": false; }; "rest": { "alias": "rest"; "required": false; }; "maxDataBindDepth": { "alias": "maxDataBindDepth"; "required": false; }; "defaultChildrenDataProperty": { "alias": "defaultChildrenDataProperty"; "required": false; }; "autoGenerateLayouts": { "alias": "autoGenerateLayouts"; "required": false; }; "expandCollapseAnimations": { "alias": "expandCollapseAnimations"; "required": false; }; "expandColWidth": { "alias": "expandColWidth"; "required": false; }; "pathSeparator": { "alias": "pathSeparator"; "required": false; }; "animationDuration": { "alias": "animationDuration"; "required": false; }; "expandTooltip": { "alias": "expandTooltip"; "required": false; }; "collapseTooltip": { "alias": "collapseTooltip"; "required": false; }; "columnLayouts": { "alias": "columnLayouts"; "required": false; }; "width": { "alias": "width"; "required": false; }; "height": { "alias": "height"; "required": false; }; "autoAdjustHeight": { "alias": "autoAdjustHeight"; "required": false; }; "avgRowHeight": { "alias": "avgRowHeight"; "required": false; }; "avgColumnWidth": { "alias": "avgColumnWidth"; "required": false; }; "defaultColumnWidth": { "alias": "defaultColumnWidth"; "required": false; }; "autoGenerateColumns": { "alias": "autoGenerateColumns"; "required": false; }; "virtualization": { "alias": "virtualization"; "required": false; }; "virtualizationMode": { "alias": "virtualizationMode"; "required": false; }; "requiresDataBinding": { "alias": "requiresDataBinding"; "required": false; }; "rowVirtualization": { "alias": "rowVirtualization"; "required": false; }; "columnVirtualization": { "alias": "columnVirtualization"; "required": false; }; "virtualizationMouseWheelStep": { "alias": "virtualizationMouseWheelStep"; "required": false; }; "adjustVirtualHeights": { "alias": "adjustVirtualHeights"; "required": false; }; "templatingEngine": { "alias": "templatingEngine"; "required": false; }; "columns": { "alias": "columns"; "required": false; }; "dataSource": { "alias": "dataSource"; "required": false; }; "dataSourceUrl": { "alias": "dataSourceUrl"; "required": false; }; "dataSourceType": { "alias": "dataSourceType"; "required": false; }; "responseDataKey": { "alias": "responseDataKey"; "required": false; }; "responseTotalRecCountKey": { "alias": "responseTotalRecCountKey"; "required": false; }; "requestType": { "alias": "requestType"; "required": false; }; "responseContentType": { "alias": "responseContentType"; "required": false; }; "showHeader": { "alias": "showHeader"; "required": false; }; "showFooter": { "alias": "showFooter"; "required": false; }; "fixedHeaders": { "alias": "fixedHeaders"; "required": false; }; "fixedFooters": { "alias": "fixedFooters"; "required": false; }; "caption": { "alias": "caption"; "required": false; }; "features": { "alias": "features"; "required": false; }; "tabIndex": { "alias": "tabIndex"; "required": false; }; "localSchemaTransform": { "alias": "localSchemaTransform"; "required": false; }; "primaryKey": { "alias": "primaryKey"; "required": false; }; "serializeTransactionLog": { "alias": "serializeTransactionLog"; "required": false; }; "autoCommit": { "alias": "autoCommit"; "required": false; }; "aggregateTransactions": { "alias": "aggregateTransactions"; "required": false; }; "autoFormat": { "alias": "autoFormat"; "required": false; }; "renderCheckboxes": { "alias": "renderCheckboxes"; "required": false; }; "updateUrl": { "alias": "updateUrl"; "required": false; }; "restSettings": { "alias": "restSettings"; "required": false; }; "alternateRowStyles": { "alias": "alternateRowStyles"; "required": false; }; "autofitLastColumn": { "alias": "autofitLastColumn"; "required": false; }; "enableHoverStyles": { "alias": "enableHoverStyles"; "required": false; }; "enableUTCDates": { "alias": "enableUTCDates"; "required": false; }; "mergeUnboundColumns": { "alias": "mergeUnboundColumns"; "required": false; }; "jsonpRequest": { "alias": "jsonpRequest"; "required": false; }; "enableResizeContainerCheck": { "alias": "enableResizeContainerCheck"; "required": false; }; "featureChooserIconDisplay": { "alias": "featureChooserIconDisplay"; "required": false; }; "scrollSettings": { "alias": "scrollSettings"; "required": false; }; "childrenDataProperty": { "alias": "childrenDataProperty"; "required": false; }; }, { "rowExpanding": "rowExpanding"; "rowExpanded": "rowExpanded"; "rowCollapsing": "rowCollapsing"; "rowCollapsed": "rowCollapsed"; "childrenPopulating": "childrenPopulating"; "childrenPopulated": "childrenPopulated"; "childGridRendered": "childGridRendered"; "childGridCreating": "childGridCreating"; "childGridCreated": "childGridCreated"; "cellClick": "cellClick"; "cellRightClick": "cellRightClick"; "dataBinding": "dataBinding"; "dataBound": "dataBound"; "rendering": "rendering"; "rendered": "rendered"; "dataRendering": "dataRendering"; "dataRendered": "dataRendered"; "headerRendering": "headerRendering"; "headerRendered": "headerRendered"; "footerRendering": "footerRendering"; "footerRendered": "footerRendered"; "headerCellRendered": "headerCellRendered"; "rowsRendering": "rowsRendering"; "rowsRendered": "rowsRendered"; "schemaGenerated": "schemaGenerated"; "columnsCollectionModified": "columnsCollectionModified"; "requestError": "requestError"; "created": "created"; "destroyed": "destroyed"; }, never, ["*"], false, never>;
}
