/// <reference types="ignite-ui" />
import { ElementRef, IterableDiffers, NgZone, KeyValueDiffers, ChangeDetectorRef, Renderer2, OnInit } from '@angular/core';
import { IgControlBase } from '../igcontrolbase/igcontrolbase';
import { ControlValueAccessor, NgModel } from '@angular/forms';
import * as i0 from "@angular/core";
export declare class IgHtmlEditorComponent extends IgControlBase<IgHtmlEditor> implements ControlValueAccessor, OnInit {
    model: NgModel;
    private zone;
    protected _model: any;
    protected _zone: any;
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, model: NgModel, zone: NgZone, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef);
    ngOnInit(): void;
    writeValue(value: any): void;
    onChange: (_: any) => void;
    onTouched: () => void;
    registerOnChange(fn: (_: any) => {}): void;
    registerOnTouched(fn: () => {}): void;
    /**
     * Returns the element on which the widget was instantiated
     */
    widget(): void;
    /**
     * Resizes the height of the workspace
     */
    resizeWorkspace(): void;
    /**
     * Gets the content of the html editor.
     *
     * @param format Returns the content as html or plain text. Values can be "text" or "html".
     */
    getContent(format: string): string;
    /**
     * Sets the content of the html editor.
     *
     * @param content The content which will be set.
     * @param format The content type: "text" or "html".
     */
    setContent(content: string, format: string): void;
    /**
     * Destroys the widget.
     */
    destroy(): void;
    /**
     * Executes htmleditor commands.
     *
     * @param actionName The command name.
     * @param args Additional parameter for the command.
     */
    executeAction(actionName: string, args?: object): void;
    /**
     * Returns true/false if the editor contents were modified or not.
     */
    isDirty(): object;
    /**
     * Returns the window object associated with the Html Editor's content editable area
     */
    contentWindow(): object;
    /**
     * Returns the document object associated with the Html Editor's content editable area
     */
    contentDocument(): object;
    /**
     * Returns the content editable associated with this Html Editor
     */
    contentEditable(): object;
    /**
     * Returns Selection object that represent the current selection in the content editable
     */
    selection(): object;
    /**
     * Returns Range object that represent the current range in the content editable
     */
    range(): object;
    /**
     * Inserts the provided content at the position of the caret.
     *
     * @param element Accepts html string, DOM element or a jQuery object.
     */
    insertAtCaret(element: object): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgHtmlEditorComponent, [null, null, null, { optional: true; }, null, null, null]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgHtmlEditorComponent, "ig-html-editor", never, { "widgetId": { "alias": "widgetId"; "required": false; }; "options": { "alias": "options"; "required": false; }; "changeDetectionInterval": { "alias": "changeDetectionInterval"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "create": { "alias": "create"; "required": false; }; "showFormattingToolbar": { "alias": "showFormattingToolbar"; "required": false; }; "showTextToolbar": { "alias": "showTextToolbar"; "required": false; }; "showInsertObjectToolbar": { "alias": "showInsertObjectToolbar"; "required": false; }; "showCopyPasteToolbar": { "alias": "showCopyPasteToolbar"; "required": false; }; "width": { "alias": "width"; "required": false; }; "height": { "alias": "height"; "required": false; }; "toolbarSettings": { "alias": "toolbarSettings"; "required": false; }; "customToolbars": { "alias": "customToolbars"; "required": false; }; "inputName": { "alias": "inputName"; "required": false; }; "value": { "alias": "value"; "required": false; }; }, { "rendered": "rendered"; "rendering": "rendering"; "actionExecuting": "actionExecuting"; "actionExecuted": "actionExecuted"; "toolbarCollapsing": "toolbarCollapsing"; "toolbarCollapsed": "toolbarCollapsed"; "toolbarExpanding": "toolbarExpanding"; "toolbarExpanded": "toolbarExpanded"; "cut": "cut"; "copy": "copy"; "paste": "paste"; "undo": "undo"; "redo": "redo"; "workspaceResized": "workspaceResized"; }, never, ["*"], false, never>;
}
