/// <reference types="ignite-ui" />
import { ElementRef, IterableDiffers, KeyValueDiffers, ChangeDetectorRef, Renderer2 } from '@angular/core';
import { IgControlBase } from '../igcontrolbase/igcontrolbase';
import * as i0 from "@angular/core";
export declare class IgLinearGaugeComponent extends IgControlBase<IgLinearGauge> {
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef);
    /**
     * Returns a string containing the names of all the ranges delimited with a \n symbol.
     */
    getRangeNames(): string;
    /**
     * Adds a new range to the linear gauge.
     *
     * @param value     The range object to be added.
     */
    addRange(value: object): void;
    /**
     * Removes a range from the linear gauge.
     *
     * @param value     A JS object with properties set as follows: name: nameOfTheRangeToRemove, remove: true
     */
    removeRange(value: object): void;
    /**
     * Updates the specified range of the linear gauge.
     *
     * @param value     The range object to be updated.
     */
    updateRange(value: object): void;
    /**
     * Gets the value for the main scale of the gauge for a given point within the bounds of the gauge.
     *
     * @param x x-coordinate
     * @param y y-coordiante
     */
    getValueForPoint(x: object, y: object): number;
    /**
     * Returns true if the main gauge needle bounding box contains the point provided, otherwise false.
     *
     * @param x The x coordinate of the point.
     * @param y The y coordinate of the point.
     */
    needleContainsPoint(x: number, y: number): void;
    /**
     * Returns information about how the linear gauge is rendered.
     */
    exportVisualData(): object;
    /**
     * Causes all pending changes of the linear gauge e.g. by changed property values to be rendered immediately.
     */
    flush(): void;
    /**
     * Destroys widget.
     */
    destroy(): void;
    /**
     * Re-polls the css styles for the widget. Use this method when the css styles have been modified.
     */
    styleUpdated(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgLinearGaugeComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgLinearGaugeComponent, "ig-linear-gauge", never, { "widgetId": { "alias": "widgetId"; "required": false; }; "options": { "alias": "options"; "required": false; }; "changeDetectionInterval": { "alias": "changeDetectionInterval"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "create": { "alias": "create"; "required": false; }; "width": { "alias": "width"; "required": false; }; "height": { "alias": "height"; "required": false; }; "ranges": { "alias": "ranges"; "required": false; }; "rangeToolTipTemplate": { "alias": "rangeToolTipTemplate"; "required": false; }; "needleToolTipTemplate": { "alias": "needleToolTipTemplate"; "required": false; }; "orientation": { "alias": "orientation"; "required": false; }; "rangeBrushes": { "alias": "rangeBrushes"; "required": false; }; "rangeOutlines": { "alias": "rangeOutlines"; "required": false; }; "minimumValue": { "alias": "minimumValue"; "required": false; }; "maximumValue": { "alias": "maximumValue"; "required": false; }; "value": { "alias": "value"; "required": false; }; "needleShape": { "alias": "needleShape"; "required": false; }; "needleName": { "alias": "needleName"; "required": false; }; "rangeInnerExtent": { "alias": "rangeInnerExtent"; "required": false; }; "scaleInnerExtent": { "alias": "scaleInnerExtent"; "required": false; }; "rangeOuterExtent": { "alias": "rangeOuterExtent"; "required": false; }; "scaleOuterExtent": { "alias": "scaleOuterExtent"; "required": false; }; "needleInnerExtent": { "alias": "needleInnerExtent"; "required": false; }; "needleOuterExtent": { "alias": "needleOuterExtent"; "required": false; }; "needleInnerBaseWidth": { "alias": "needleInnerBaseWidth"; "required": false; }; "needleOuterBaseWidth": { "alias": "needleOuterBaseWidth"; "required": false; }; "needleInnerPointWidth": { "alias": "needleInnerPointWidth"; "required": false; }; "needleOuterPointWidth": { "alias": "needleOuterPointWidth"; "required": false; }; "needleInnerPointExtent": { "alias": "needleInnerPointExtent"; "required": false; }; "needleOuterPointExtent": { "alias": "needleOuterPointExtent"; "required": false; }; "interval": { "alias": "interval"; "required": false; }; "ticksPostInitial": { "alias": "ticksPostInitial"; "required": false; }; "ticksPreTerminal": { "alias": "ticksPreTerminal"; "required": false; }; "labelInterval": { "alias": "labelInterval"; "required": false; }; "labelExtent": { "alias": "labelExtent"; "required": false; }; "labelsPostInitial": { "alias": "labelsPostInitial"; "required": false; }; "labelsPreTerminal": { "alias": "labelsPreTerminal"; "required": false; }; "minorTickCount": { "alias": "minorTickCount"; "required": false; }; "tickStartExtent": { "alias": "tickStartExtent"; "required": false; }; "tickEndExtent": { "alias": "tickEndExtent"; "required": false; }; "tickStrokeThickness": { "alias": "tickStrokeThickness"; "required": false; }; "tickBrush": { "alias": "tickBrush"; "required": false; }; "fontBrush": { "alias": "fontBrush"; "required": false; }; "needleBreadth": { "alias": "needleBreadth"; "required": false; }; "needleBrush": { "alias": "needleBrush"; "required": false; }; "needleOutline": { "alias": "needleOutline"; "required": false; }; "needleStrokeThickness": { "alias": "needleStrokeThickness"; "required": false; }; "minorTickStartExtent": { "alias": "minorTickStartExtent"; "required": false; }; "minorTickEndExtent": { "alias": "minorTickEndExtent"; "required": false; }; "minorTickStrokeThickness": { "alias": "minorTickStrokeThickness"; "required": false; }; "minorTickBrush": { "alias": "minorTickBrush"; "required": false; }; "isScaleInverted": { "alias": "isScaleInverted"; "required": false; }; "backingBrush": { "alias": "backingBrush"; "required": false; }; "backingOutline": { "alias": "backingOutline"; "required": false; }; "backingStrokeThickness": { "alias": "backingStrokeThickness"; "required": false; }; "backingInnerExtent": { "alias": "backingInnerExtent"; "required": false; }; "backingOuterExtent": { "alias": "backingOuterExtent"; "required": false; }; "scaleStartExtent": { "alias": "scaleStartExtent"; "required": false; }; "scaleEndExtent": { "alias": "scaleEndExtent"; "required": false; }; "scaleBrush": { "alias": "scaleBrush"; "required": false; }; "scaleOutline": { "alias": "scaleOutline"; "required": false; }; "scaleStrokeThickness": { "alias": "scaleStrokeThickness"; "required": false; }; "isNeedleDraggingEnabled": { "alias": "isNeedleDraggingEnabled"; "required": false; }; "transitionDuration": { "alias": "transitionDuration"; "required": false; }; "showToolTipTimeout": { "alias": "showToolTipTimeout"; "required": false; }; "showToolTip": { "alias": "showToolTip"; "required": false; }; "font": { "alias": "font"; "required": false; }; "pixelScalingRatio": { "alias": "pixelScalingRatio"; "required": false; }; }, { "formatLabel": "formatLabel"; "alignLabel": "alignLabel"; "valueChanged": "valueChanged"; }, never, ["*"], false, never>;
}
