/// <reference types="ignite-ui" />
import { IgControlBase } from '../igcontrolbase/igcontrolbase';
import { ElementRef, IterableDiffers, KeyValueDiffers, ChangeDetectorRef, Renderer2, OnInit } from '@angular/core';
import * as i0 from "@angular/core";
export declare class IgPieChartComponent extends IgControlBase<IgPieChart> implements OnInit {
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef);
    private _dataSource;
    option(): void;
    set dataSource(value: any);
    ngOnInit(): void;
    /**
     * Adds a new item to the data source and notifies the chart.
     *
     * @param item     the new item that will be added to the data source.
     */
    addItem(item: object): void;
    /**
     * Inserts a new item to the data source and notifies the chart.
     *
     * @param item     the new item that will be inserted in the data source.
     * @param index     The index in the data source where the new item will be inserted.
     */
    insertItem(item: object, index: number): void;
    /**
     * Deletes an item from the data source and notifies the chart.
     *
     * @param index     The index in the data source from where the item will be been removed.
     */
    removeItem(index: number): void;
    /**
     * Updates an item in the data source and notifies the chart.
     *
     * @param index     The index in the data source that we want to change.
     * @param item     the new item that we want to set in the data source.
     */
    setItem(index: number, item: object): void;
    /**
     * Exports the chart to a PNG image.
     *
     * @param width     The width of the image.
     * @param height     The height of the image.
     */
    exportImage(width?: object, height?: object): object;
    /**
     * Destroys the widget.
     */
    destroy(): void;
    /**
     * Returns the ID of parent element holding the chart.
     */
    id(): string;
    /**
     * Returns the element holding the chart.
     */
    widget(): void;
    /**
     * Creates a print preview page with the chart, hiding all other elements on the page.
     */
    print(): void;
    /**
     * Exports visual data from the pie chart to aid in unit testing
     */
    exportVisualData(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgPieChartComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgPieChartComponent, "ig-pie-chart", never, { "widgetId": { "alias": "widgetId"; "required": false; }; "options": { "alias": "options"; "required": false; }; "changeDetectionInterval": { "alias": "changeDetectionInterval"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "create": { "alias": "create"; "required": false; }; "width": { "alias": "width"; "required": false; }; "height": { "alias": "height"; "required": false; }; "dataSource": { "alias": "dataSource"; "required": false; }; "dataSourceUrl": { "alias": "dataSourceUrl"; "required": false; }; "dataSourceType": { "alias": "dataSourceType"; "required": false; }; "responseDataKey": { "alias": "responseDataKey"; "required": false; }; "valueMemberPath": { "alias": "valueMemberPath"; "required": false; }; "labelMemberPath": { "alias": "labelMemberPath"; "required": false; }; "dataValue": { "alias": "dataValue"; "required": false; }; "dataLabel": { "alias": "dataLabel"; "required": false; }; "labelsPosition": { "alias": "labelsPosition"; "required": false; }; "labelOuterColor": { "alias": "labelOuterColor"; "required": false; }; "labelInnerColor": { "alias": "labelInnerColor"; "required": false; }; "selectionMode": { "alias": "selectionMode"; "required": false; }; "selectedItem": { "alias": "selectedItem"; "required": false; }; "selectedItems": { "alias": "selectedItems"; "required": false; }; "leaderLineVisibility": { "alias": "leaderLineVisibility"; "required": false; }; "leaderLineType": { "alias": "leaderLineType"; "required": false; }; "leaderLineMargin": { "alias": "leaderLineMargin"; "required": false; }; "othersCategoryThreshold": { "alias": "othersCategoryThreshold"; "required": false; }; "formatLabel": { "alias": "formatLabel"; "required": false; }; "othersCategoryStyle": { "alias": "othersCategoryStyle"; "required": false; }; "othersCategoryType": { "alias": "othersCategoryType"; "required": false; }; "othersCategoryText": { "alias": "othersCategoryText"; "required": false; }; "explodedRadius": { "alias": "explodedRadius"; "required": false; }; "radiusFactor": { "alias": "radiusFactor"; "required": false; }; "allowSliceSelection": { "alias": "allowSliceSelection"; "required": false; }; "allowSliceExplosion": { "alias": "allowSliceExplosion"; "required": false; }; "explodedSlices": { "alias": "explodedSlices"; "required": false; }; "selectedSlices": { "alias": "selectedSlices"; "required": false; }; "showTooltip": { "alias": "showTooltip"; "required": false; }; "tooltipTemplate": { "alias": "tooltipTemplate"; "required": false; }; "legend": { "alias": "legend"; "required": false; }; "labelExtent": { "alias": "labelExtent"; "required": false; }; "startAngle": { "alias": "startAngle"; "required": false; }; "sweepDirection": { "alias": "sweepDirection"; "required": false; }; "selectedStyle": { "alias": "selectedStyle"; "required": false; }; "brushes": { "alias": "brushes"; "required": false; }; "outlines": { "alias": "outlines"; "required": false; }; "legendItemTemplate": { "alias": "legendItemTemplate"; "required": false; }; "legendItemBadgeTemplate": { "alias": "legendItemBadgeTemplate"; "required": false; }; "textStyle": { "alias": "textStyle"; "required": false; }; "theme": { "alias": "theme"; "required": false; }; }, { "tooltipShowing": "tooltipShowing"; "tooltipShown": "tooltipShown"; "tooltipHiding": "tooltipHiding"; "tooltipHidden": "tooltipHidden"; "browserNotSupported": "browserNotSupported"; "sliceClick": "sliceClick"; "labelClick": "labelClick"; "selectedItemChanging": "selectedItemChanging"; "selectedItemChanged": "selectedItemChanged"; "selectedItemsChanging": "selectedItemsChanging"; "selectedItemsChanged": "selectedItemsChanged"; }, never, ["*"], false, never>;
}
