/// <reference types="ignite-ui" />
import { ElementRef, IterableDiffers, KeyValueDiffers, ChangeDetectorRef, Renderer2, OnInit } from '@angular/core';
import { IgControlBase } from '../igcontrolbase/igcontrolbase';
import * as i0 from "@angular/core";
export declare class IgPivotGridComponent extends IgControlBase<IgPivotGrid> implements OnInit {
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef);
    set dataSource(value: any);
    private _dataSource;
    option(): void;
    ngOnInit(): void;
    /**
     * Returns the igGrid instance used to render the OLAP data.
     */
    grid(): object;
    /**
     * Triggers an update on the data source and the igPivotGrid.
     */
    updateGrid(): void;
    /**
     * Expands a member from the data source and returns true if the expand succeeds.
     * If the data source has a pending update, the method will return false.
     * Note that igPivotGrid to will display the expanded result after the data source is updated.
     *
     * @param tupleLocation The name of the parent axis - 'columnAxis' or 'rowAxis'.
     * @param tupleIndex The index of the containing tuple.
     * This index should correspond to the position of the tuple in the original unsorted result of the data source.
     * @param memberIndex The index of the member in the tuple.
     * This index should correspond to the position of the member in the original unsorted result of the data source.
     * @param shouldUpdate A flag indicating whether the data source should be updated after the expand.
     */
    expandTupleMember(tupleLocation: string, tupleIndex: number, memberIndex: number, shouldUpdate?: boolean): boolean;
    /**
     * Collapses a member from the data source and returns true if the collapse succeeds.
     * If the data source has a pending update, the method will return false.
     * Note that igPivotGrid to will display the expanded result after the data source is updated.
     *
     * @param tupleLocation The name of the parent axis - 'columnAxis' or 'rowAxis'.
     * @param tupleIndex The index of the containing tuple.
     * This index should correspond to the position of the tuple in the original unsorted result of the data source.
     * @param memberIndex The index of the member in the tuple.
     * This index should correspond to the position of the member in the original unsorted result of the data source.
     * @param shouldUpdate A flag indicating whether the data source should be updated after the expand.
     */
    collapseTupleMember(tupleLocation: string, tupleIndex: number, memberIndex: number, shouldUpdate?: boolean): boolean;
    /**
     * Returns an array with the applied sort directions on the igPivotGrid's columns.
     * The returned array contains objects with the following properties:
     *             memberNames: The names of the members in the tuple.
     *             tupleIndex: The index of the tuple on the column axis in the original unsorted result.
     *             sortDirection: The direction of the sort - ascending or descending.
     */
    appliedColumnSortDirections(): any[];
    /**
     * Returns an array with the applied level sort direction items, which were used for the sorting of the header cells.
     * The returned array contains objects with the following properties:
     *             levelUniqueName: Specifies the unique name of the level, which was sorted.
     *             sortDirection: The direction of the header sort - ascending or descending.
     */
    appliedLevelSortDirections(): any[];
    /**
     * Destroy is part of the jQuery UI widget API and does the following:
     *             1. Remove custom CSS classes that were added.
     *             2. Unwrap any wrapping elements such as scrolling divs and other containers.
     *             3. Unbind all events that were bound.
     */
    destroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgPivotGridComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgPivotGridComponent, "ig-pivot-grid", never, { "widgetId": { "alias": "widgetId"; "required": false; }; "options": { "alias": "options"; "required": false; }; "changeDetectionInterval": { "alias": "changeDetectionInterval"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "create": { "alias": "create"; "required": false; }; "width": { "alias": "width"; "required": false; }; "height": { "alias": "height"; "required": false; }; "dataSource": { "alias": "dataSource"; "required": false; }; "dataSourceOptions": { "alias": "dataSourceOptions"; "required": false; }; "deferUpdate": { "alias": "deferUpdate"; "required": false; }; "isParentInFrontForColumns": { "alias": "isParentInFrontForColumns"; "required": false; }; "isParentInFrontForRows": { "alias": "isParentInFrontForRows"; "required": false; }; "compactColumnHeaders": { "alias": "compactColumnHeaders"; "required": false; }; "compactRowHeaders": { "alias": "compactRowHeaders"; "required": false; }; "rowHeadersLayout": { "alias": "rowHeadersLayout"; "required": false; }; "compactColumnHeaderIndentation": { "alias": "compactColumnHeaderIndentation"; "required": false; }; "compactRowHeaderIndentation": { "alias": "compactRowHeaderIndentation"; "required": false; }; "rowHeaderLinkGroupIndentation": { "alias": "rowHeaderLinkGroupIndentation"; "required": false; }; "treeRowHeaderIndentation": { "alias": "treeRowHeaderIndentation"; "required": false; }; "defaultRowHeaderWidth": { "alias": "defaultRowHeaderWidth"; "required": false; }; "allowSorting": { "alias": "allowSorting"; "required": false; }; "firstSortDirection": { "alias": "firstSortDirection"; "required": false; }; "allowHeaderRowsSorting": { "alias": "allowHeaderRowsSorting"; "required": false; }; "allowHeaderColumnsSorting": { "alias": "allowHeaderColumnsSorting"; "required": false; }; "levelSortDirections": { "alias": "levelSortDirections"; "required": false; }; "defaultLevelSortBehavior": { "alias": "defaultLevelSortBehavior"; "required": false; }; "firstLevelSortDirection": { "alias": "firstLevelSortDirection"; "required": false; }; "gridOptions": { "alias": "gridOptions"; "required": false; }; "dragAndDropSettings": { "alias": "dragAndDropSettings"; "required": false; }; "dropDownParent": { "alias": "dropDownParent"; "required": false; }; "disableRowsDropArea": { "alias": "disableRowsDropArea"; "required": false; }; "disableColumnsDropArea": { "alias": "disableColumnsDropArea"; "required": false; }; "disableMeasuresDropArea": { "alias": "disableMeasuresDropArea"; "required": false; }; "disableFiltersDropArea": { "alias": "disableFiltersDropArea"; "required": false; }; "hideRowsDropArea": { "alias": "hideRowsDropArea"; "required": false; }; "hideColumnsDropArea": { "alias": "hideColumnsDropArea"; "required": false; }; "hideMeasuresDropArea": { "alias": "hideMeasuresDropArea"; "required": false; }; "hideFiltersDropArea": { "alias": "hideFiltersDropArea"; "required": false; }; "customMoveValidation": { "alias": "customMoveValidation"; "required": false; }; }, { "dataSourceInitialized": "dataSourceInitialized"; "dataSourceUpdated": "dataSourceUpdated"; "pivotGridHeadersRendered": "pivotGridHeadersRendered"; "pivotGridRendered": "pivotGridRendered"; "tupleMemberExpanding": "tupleMemberExpanding"; "tupleMemberExpanded": "tupleMemberExpanded"; "tupleMemberCollapsing": "tupleMemberCollapsing"; "tupleMemberCollapsed": "tupleMemberCollapsed"; "sorting": "sorting"; "sorted": "sorted"; "headersSorting": "headersSorting"; "headersSorted": "headersSorted"; "dragStart": "dragStart"; "drag": "drag"; "dragStop": "dragStop"; "metadataDropping": "metadataDropping"; "metadataDropped": "metadataDropped"; "metadataRemoving": "metadataRemoving"; "metadataRemoved": "metadataRemoved"; "filterDropDownOpening": "filterDropDownOpening"; "filterDropDownOpened": "filterDropDownOpened"; "filterMembersLoaded": "filterMembersLoaded"; "filterDropDownOk": "filterDropDownOk"; "filterDropDownClosing": "filterDropDownClosing"; "filterDropDownClosed": "filterDropDownClosed"; }, never, ["*"], false, never>;
}
