/// <reference types="ignite-ui" />
import { ElementRef, IterableDiffers, KeyValueDiffers, ChangeDetectorRef, Renderer2 } from '@angular/core';
import { IgControlBase } from '../igcontrolbase/igcontrolbase';
import * as i0 from "@angular/core";
export declare class IgRadialGaugeComponent extends IgControlBase<IgRadialGauge> {
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef);
    /**
     * Returns a string containing the names of all the ranges delimited with a \n symbol.
     */
    getRangeNames(): string;
    /**
     * Adds a new range to the radial gauge.
     *
     * @param value value
     */
    addRange(value: object): void;
    /**
     * Removes a specified range.
     *
     * @param value value
     */
    removeRange(value: object): void;
    /**
     * Updates the range.
     *
     * @param value value
     */
    updateRange(value: object): void;
    /**
     * Clears the ranges in the radial gauge.
     */
    clearRanges(): void;
    /**
     * Scales a value on the gauge's main scale to an angle around the center point of the gauge, in radians.
     *
     * @param value value
     */
    scaleValue(value: object): void;
    /**
     * Unscales a value from an angle in radians to the represented value along the main scale of the gauge.
     *
     * @param value value
     */
    unscaleValue(value: object): void;
    /**
     * Gets the value for the main scale of the gauge for a given point within the bounds of the gauge.
     *
     * @param x x-coordinate
     * @param y y-coordinate
     */
    getValueForPoint(x: object, y: object): number;
    /**
     * Gets the point on the gauge for a given scale value and extent.
     *
     * @param value value
     * @param extent extent
     */
    getPointForValue(value: object, extent: object): void;
    /**
     * Returns true if the main gauge needle bounding box contains the point provided, otherwise false.
     *
     * @param x x-coordinate
     * @param y y-coordinate
     */
    needleContainsPoint(x: object, y: object): void;
    /**
     * Exports the visual data for the radial gauge.
     */
    exportVisualData(): void;
    /**
     * Flushes the gauge.
     */
    flush(): void;
    /**
     * Destroys widget.
     */
    destroy(): void;
    /**
     * Returns true if the style was updated for the radial gauge.
     */
    styleUpdated(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgRadialGaugeComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgRadialGaugeComponent, "ig-radial-gauge", never, { "widgetId": { "alias": "widgetId"; "required": false; }; "options": { "alias": "options"; "required": false; }; "changeDetectionInterval": { "alias": "changeDetectionInterval"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "create": { "alias": "create"; "required": false; }; "width": { "alias": "width"; "required": false; }; "height": { "alias": "height"; "required": false; }; "ranges": { "alias": "ranges"; "required": false; }; "rangeBrushes": { "alias": "rangeBrushes"; "required": false; }; "rangeOutlines": { "alias": "rangeOutlines"; "required": false; }; "minimumValue": { "alias": "minimumValue"; "required": false; }; "maximumValue": { "alias": "maximumValue"; "required": false; }; "interval": { "alias": "interval"; "required": false; }; "centerX": { "alias": "centerX"; "required": false; }; "centerY": { "alias": "centerY"; "required": false; }; "value": { "alias": "value"; "required": false; }; "scaleStartAngle": { "alias": "scaleStartAngle"; "required": false; }; "scaleEndAngle": { "alias": "scaleEndAngle"; "required": false; }; "scaleSweepDirection": { "alias": "scaleSweepDirection"; "required": false; }; "transitionDuration": { "alias": "transitionDuration"; "required": false; }; "transitionEasingFunction": { "alias": "transitionEasingFunction"; "required": false; }; "needleBrush": { "alias": "needleBrush"; "required": false; }; "needleOutline": { "alias": "needleOutline"; "required": false; }; "needleStartExtent": { "alias": "needleStartExtent"; "required": false; }; "needleEndExtent": { "alias": "needleEndExtent"; "required": false; }; "needleShape": { "alias": "needleShape"; "required": false; }; "needleStartWidthRatio": { "alias": "needleStartWidthRatio"; "required": false; }; "needleEndWidthRatio": { "alias": "needleEndWidthRatio"; "required": false; }; "needleBaseFeatureWidthRatio": { "alias": "needleBaseFeatureWidthRatio"; "required": false; }; "needleBaseFeatureExtent": { "alias": "needleBaseFeatureExtent"; "required": false; }; "needlePointFeatureWidthRatio": { "alias": "needlePointFeatureWidthRatio"; "required": false; }; "needlePointFeatureExtent": { "alias": "needlePointFeatureExtent"; "required": false; }; "needlePivotWidthRatio": { "alias": "needlePivotWidthRatio"; "required": false; }; "needlePivotInnerWidthRatio": { "alias": "needlePivotInnerWidthRatio"; "required": false; }; "needlePivotShape": { "alias": "needlePivotShape"; "required": false; }; "scaleStartExtent": { "alias": "scaleStartExtent"; "required": false; }; "needlePivotBrush": { "alias": "needlePivotBrush"; "required": false; }; "needlePivotOutline": { "alias": "needlePivotOutline"; "required": false; }; "needleStrokeThickness": { "alias": "needleStrokeThickness"; "required": false; }; "needlePivotStrokeThickness": { "alias": "needlePivotStrokeThickness"; "required": false; }; "scaleEndExtent": { "alias": "scaleEndExtent"; "required": false; }; "labelExtent": { "alias": "labelExtent"; "required": false; }; "labelInterval": { "alias": "labelInterval"; "required": false; }; "tickStartExtent": { "alias": "tickStartExtent"; "required": false; }; "tickEndExtent": { "alias": "tickEndExtent"; "required": false; }; "tickStrokeThickness": { "alias": "tickStrokeThickness"; "required": false; }; "tickBrush": { "alias": "tickBrush"; "required": false; }; "fontBrush": { "alias": "fontBrush"; "required": false; }; "minorTickStartExtent": { "alias": "minorTickStartExtent"; "required": false; }; "minorTickEndExtent": { "alias": "minorTickEndExtent"; "required": false; }; "minorTickStrokeThickness": { "alias": "minorTickStrokeThickness"; "required": false; }; "minorTickBrush": { "alias": "minorTickBrush"; "required": false; }; "minorTickCount": { "alias": "minorTickCount"; "required": false; }; "scaleBrush": { "alias": "scaleBrush"; "required": false; }; "backingBrush": { "alias": "backingBrush"; "required": false; }; "backingOutline": { "alias": "backingOutline"; "required": false; }; "backingStrokeThickness": { "alias": "backingStrokeThickness"; "required": false; }; "backingOuterExtent": { "alias": "backingOuterExtent"; "required": false; }; "backingOversweep": { "alias": "backingOversweep"; "required": false; }; "scaleOversweep": { "alias": "scaleOversweep"; "required": false; }; "scaleOversweepShape": { "alias": "scaleOversweepShape"; "required": false; }; "backingCornerRadius": { "alias": "backingCornerRadius"; "required": false; }; "backingInnerExtent": { "alias": "backingInnerExtent"; "required": false; }; "backingShape": { "alias": "backingShape"; "required": false; }; "radiusMultiplier": { "alias": "radiusMultiplier"; "required": false; }; "duplicateLabelOmissionStrategy": { "alias": "duplicateLabelOmissionStrategy"; "required": false; }; "isNeedleDraggingEnabled": { "alias": "isNeedleDraggingEnabled"; "required": false; }; "isNeedleDraggingConstrained": { "alias": "isNeedleDraggingConstrained"; "required": false; }; "font": { "alias": "font"; "required": false; }; "transitionProgress": { "alias": "transitionProgress"; "required": false; }; "pixelScalingRatio": { "alias": "pixelScalingRatio"; "required": false; }; }, { "formatLabel": "formatLabel"; "alignLabel": "alignLabel"; "valueChanged": "valueChanged"; }, never, ["*"], false, never>;
}
