/// <reference types="ignite-ui" />
import { ElementRef, IterableDiffers, KeyValueDiffers, ChangeDetectorRef, SimpleChanges, Renderer2, OnInit, OnChanges, DoCheck } from '@angular/core';
import { IgControlBase } from '../igcontrolbase/igcontrolbase';
import * as i0 from "@angular/core";
export declare class IgTreeComponent extends IgControlBase<IgTree> implements OnInit, OnChanges, DoCheck {
    private _dataSource;
    private _changes;
    set dataSource(value: any);
    bindings: IgTreeBindings;
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngDoCheck(): void;
    addItem(item: any, index: any): void;
    deleteItem(item: any, index: any): void;
    dataSourceApplyChanges(changes: any): void;
    updateItem(item: any, value: any, key: any): void;
    markForCheck(): void;
    /**
     * Performs databinding on the igTree.
     */
    dataBind(): void;
    /**
     * Toggles the checkstate of a node if checkboxMode is not set to off, otherwise does nothing.
     *
     * @param node     Specifies the node element the checkbox of which would be toggled.
     * @param event     Indicates the browser event which triggered this action, if this is not an API call.
     */
    toggleCheckstate(node: object, event?: object): void;
    /**
     * Toggles the collapse/expand state for the specified node.
     *
     * @param node     Specifies the node element the checkbox of which would be toggled.
     * @param event     Indicates the browser event which triggered this action, if this is not an API call.
     */
    toggle(node: object, event?: object): void;
    /**
     * Expands the tree down to the specified node and selects the node if specified.
     *
     * @param node     Specifies the node element down to which the tree would be expanded.
     * @param toSelect     Specifies the whether to select the node after expanding to it.
     */
    expandToNode(node: object, toSelect?: boolean): void;
    /**
     * Expands the specified node.
     *
     * @param node     Specifies the node element to expand.
     */
    expand(node: object): void;
    /**
     * Collapses the specified node.
     *
     * @param node     Specifies the node element to collapse.
     */
    collapse(node: object): void;
    /**
     * Retrieves the parent node element of the specified node element.
     *
     * @param node     Specifies the jQuery selected node element to collapse.
     */
    parentNode(node: object): object;
    /**
     * Retrieves the jQuery element of the node with the specified path.
     *
     * @param nodePath     Specifies the path to the required node.
     */
    nodeByPath(nodePath: string): object;
    /**
     * Retrieves the jQuery element of the node with the specified value.
     *
     * @param value     Specifies the value of the required node.
     */
    nodesByValue(value: string): object;
    /**
     * Retrieves all the node objects for the nodes that have their checkboxes checked.
     */
    checkedNodes(): any[];
    /**
     * Retrieves all the node objects for the nodes that have their checkboxes unchecked.
     */
    uncheckedNodes(): any[];
    /**
     * Retrieves all the node objects for the nodes that have their checkboxes partially checked.
     */
    partiallyCheckedNodes(): any[];
    /**
     * Selects a node.
     *
     * @param node     Specifies the node element to be selected.
     * @param event     Indicates the browser event which triggered this action, if this is not an API call.
     */
    select(node: object, event?: object): void;
    /**
     * Deselects the specified node.
     *
     * @param node     Specifies the node element to be deselected.
     */
    deselect(node: object): void;
    /**
     * Deselects all the selected nodes.
     */
    clearSelection(): void;
    /**
     * Retrieves the node object for the selected node.
     */
    selectedNode(): object;
    /**
     * Retrieves all node objects with the specified text (case sensitive).
     *
     * @param text     The text to search for.
     * @param parent     The node element to start the search from. If not specified then search would start from the root of the tree.
     */
    findNodesByText(text: string, parent?: object): any[];
    /**
     * Retrieves all node objects for the immediate children of the specified parent with the specified text (case sensitive).
     *
     * @param text     The text to search for.
     * @param parent     The node element the children of which would be searched.
     */
    findImmediateNodesByText(text: string, parent?: object): any[];
    /**
     * Retrieves the n-th jQuery node element child of the specified parent.
     *
     * @param index     Specifies the index the node at which to be retrieved.
     * @param parent     The parent node element to start the search from.
     */
    nodeByIndex(index: number, parent?: object): object;
    /**
     * Retrieves a node object for the specified node element.
     *
     * @param element     Specifies the node element.
     */
    nodeFromElement(element: object): object;
    /**
     * Retrieves a node object collection of the immediate children of the provided node element.
     *
     * @param parent     Specifies the node element.
     */
    children(parent: object): any[];
    /**
     * Retrieves a node object collection of the immediate children of the node with the provided path.
     *
     * @param path     Specifies the path of the node the children of which are to be retrieved.
     */
    childrenByPath(path: string): any[];
    /**
     * Returns true if the provided node element is selected and false otherwise.
     *
     * @param node     Specifies the node element.
     */
    isSelected(node: object): boolean;
    /**
     * Returns true if the provided node element is expanded and false otherwise.
     *
     * @param node     Specifies the node element.
     */
    isExpanded(node: object): boolean;
    /**
     * Returns true if the provided node element has its checkbox checkstate checked and false otherwise.
     *
     * @param node     Specifies the node element.
     */
    isChecked(node: object): boolean;
    /**
     * Returns the specified node checkstate.
     *
     * @param node     Specifies the node element.
     */
    checkState(node: object): string;
    /**
     * Adds a new array of nodes to the tree. New nodes are appended to the root or to a specified parent node, at a specified index.
     *
     * @param node     Specifies the data used to create the new nodeс.
     * @param parent     Specifies the element of the parent node the nodes are to be appended to.
     * @param nodeIndex     Specifies the index at which the nodes to be inserted.
     */
    addNode(node: object, parent?: object, nodeIndex?: number): void;
    /**
     * Removes the node with with the specified path and all of its children.
     *
     * @param path     Specifies the path of the node to be removed.
     */
    removeAt(path: string): void;
    /**
     * Removing all the nodes with the specified value.
     *
     * @param value     Specifies the value of the nodes to be removed.
     */
    removeNodesByValue(value: string): void;
    /**
     * Performs a UI update on the provided node element with the provided data.
     *
     * @param element     Specifies the node to be updated.
     * @param data     Specifies the new data item the node would update according to.
     */
    applyChangesToNode(element: object, data: object): void;
    /**
     * Returns the transaction log stack.
     */
    transactionLog(): any[];
    /**
     * Returns the data for the node with specified path.
     *
     * @param path     Specifies the node path for which the data is returned.
     */
    nodeDataFor(path: string): object;
    /**
     * Destructor for the igTree widget.
     */
    destroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgTreeComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgTreeComponent, "ig-tree", never, { "widgetId": { "alias": "widgetId"; "required": false; }; "options": { "alias": "options"; "required": false; }; "changeDetectionInterval": { "alias": "changeDetectionInterval"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "create": { "alias": "create"; "required": false; }; "width": { "alias": "width"; "required": false; }; "height": { "alias": "height"; "required": false; }; "checkboxMode": { "alias": "checkboxMode"; "required": false; }; "singleBranchExpand": { "alias": "singleBranchExpand"; "required": false; }; "hotTracking": { "alias": "hotTracking"; "required": false; }; "parentNodeImageUrl": { "alias": "parentNodeImageUrl"; "required": false; }; "parentNodeImageClass": { "alias": "parentNodeImageClass"; "required": false; }; "parentNodeImageTooltip": { "alias": "parentNodeImageTooltip"; "required": false; }; "leafNodeImageUrl": { "alias": "leafNodeImageUrl"; "required": false; }; "leafNodeImageClass": { "alias": "leafNodeImageClass"; "required": false; }; "leafNodeImageTooltip": { "alias": "leafNodeImageTooltip"; "required": false; }; "animationDuration": { "alias": "animationDuration"; "required": false; }; "pathSeparator": { "alias": "pathSeparator"; "required": false; }; "dataSource": { "alias": "dataSource"; "required": false; }; "dataSourceUrl": { "alias": "dataSourceUrl"; "required": false; }; "dataSourceType": { "alias": "dataSourceType"; "required": false; }; "responseDataKey": { "alias": "responseDataKey"; "required": false; }; "responseDataType": { "alias": "responseDataType"; "required": false; }; "requestType": { "alias": "requestType"; "required": false; }; "responseContentType": { "alias": "responseContentType"; "required": false; }; "initialExpandDepth": { "alias": "initialExpandDepth"; "required": false; }; "loadOnDemand": { "alias": "loadOnDemand"; "required": false; }; "bindings": { "alias": "bindings"; "required": false; }; "defaultNodeTarget": { "alias": "defaultNodeTarget"; "required": false; }; "dragAndDrop": { "alias": "dragAndDrop"; "required": false; }; "updateUrl": { "alias": "updateUrl"; "required": false; }; "dragAndDropSettings": { "alias": "dragAndDropSettings"; "required": false; }; }, { "dataBinding": "dataBinding"; "dataBound": "dataBound"; "rendering": "rendering"; "rendered": "rendered"; "selectionChanging": "selectionChanging"; "selectionChanged": "selectionChanged"; "nodeCheckstateChanging": "nodeCheckstateChanging"; "nodeCheckstateChanged": "nodeCheckstateChanged"; "nodePopulating": "nodePopulating"; "nodePopulated": "nodePopulated"; "nodeCollapsing": "nodeCollapsing"; "nodeCollapsed": "nodeCollapsed"; "nodeExpanding": "nodeExpanding"; "nodeExpanded": "nodeExpanded"; "nodeClick": "nodeClick"; "nodeDoubleClick": "nodeDoubleClick"; "dragStart": "dragStart"; "drag": "drag"; "dragStop": "dragStop"; "nodeDropping": "nodeDropping"; "nodeDropped": "nodeDropped"; }, never, ["*"], false, never>;
}
