/// <reference types="ignite-ui" />
import { ElementRef, IterableDiffers, KeyValueDiffers, ChangeDetectorRef, Renderer2 } from '@angular/core';
import { IgGridBase } from '../iggrid/iggridbase';
import * as i0 from "@angular/core";
export declare class IgTreeGridComponent extends IgGridBase<IgTreeGrid> {
    childDataKey: string;
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef);
    deleteRow(id: any): void;
    updateRow(rec: any, currValue: any, key: any): void;
    markForCheck(): void;
    /**
     * Clears the transaction log (delegates to igDataSource).
     * Note that this does not update the UI. In case the UI must be updated,
     * set the second parameter "updateUI" to true, which will trigger a call to dataBind() to re-render the contents.
     *
     * @param rowId     If specified, will only rollback the transactions with that row id.
     * @param updateUI     Whether to update the UI or not.
     */
    rollback(rowId?: object, updateUI?: boolean): any[];
    /**
     * Causes the treegrid to data bind to the data source (local or remote) , and re-render all of the data
     */
    dataBind(): void;
    /**
     * Toggle row by specified row or row identifier
     *
     * @param row     jQuery table row object or a row id.
     * @param callback     Specifies a custom function to be called when row is expanded/collapsed.
     * The callback has 4 arguments- a reference to the current context(this),
     * object that holds 2 properties(unfixedRow - DOM representation of the unfixed row,
     * fixedRow - DOM representation of the fixed row, if there is no fixed columns it is undefined),
     * reference to the dataRecord, expand - specifies whether row is expanded
     */
    toggleRow(row: object, callback?: () => void): void;
    /**
     * Expands a parent row by specified row or row identifier
     *
     * @param row     jQuery table row object or a row id.
     * @param callback     Specifies a custom function to be called when row is expanded/collapsed.
     * The callback has 4 arguments- a reference to the current context(this),
     * object that holds 2 properties(unfixedRow - DOM representation of the unfixed row,
     * fixedRow - DOM representation of the fixed row, if there is no fixed columns it is undefined),
     * reference to the dataRecord, expand - specifies whether row is expanded
     */
    expandRow(row: object, callback?: () => void): void;
    /**
     * Collapses a parent row by specified row or row identifier
     *
     * @param row     jQuery table row object, raw DOM row object or a row id.
     * @param callback     Specifies a custom function to be called when row is expanded/collapsed.
     * The callback has 4 arguments- a reference to the current context(this),
     * object that holds 2 properties(unfixedRow - DOM representation of the unfixed row,
     * fixedRow - DOM representation of the fixed row, if there is no fixed columns it is undefined),
     * reference to the dataRecord, expand - specifies whether row is expanded
     */
    collapseRow(row: object, callback?: () => void): void;
    /**
     * Adds a new row (TR) to the grid as a child of a specific row, by taking a data row object.
     * Assumes the record will have the primary key.
     *
     * @param rec     The data row JavaScript object.
     * @param parentId     Identifier/key of the targeted parent row. If missing, then the new row is rendered to the bottom of the grid.
     */
    renderNewChild(rec: object, parentId?: string): void;
    /**
     * Destroys igTreeGrid
     */
    destroy(): object;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgTreeGridComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgTreeGridComponent, "ig-tree-grid", never, { "widgetId": { "alias": "widgetId"; "required": false; }; "options": { "alias": "options"; "required": false; }; "changeDetectionInterval": { "alias": "changeDetectionInterval"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "create": { "alias": "create"; "required": false; }; "width": { "alias": "width"; "required": false; }; "height": { "alias": "height"; "required": false; }; "autoAdjustHeight": { "alias": "autoAdjustHeight"; "required": false; }; "avgRowHeight": { "alias": "avgRowHeight"; "required": false; }; "avgColumnWidth": { "alias": "avgColumnWidth"; "required": false; }; "defaultColumnWidth": { "alias": "defaultColumnWidth"; "required": false; }; "autoGenerateColumns": { "alias": "autoGenerateColumns"; "required": false; }; "virtualization": { "alias": "virtualization"; "required": false; }; "virtualizationMode": { "alias": "virtualizationMode"; "required": false; }; "requiresDataBinding": { "alias": "requiresDataBinding"; "required": false; }; "rowVirtualization": { "alias": "rowVirtualization"; "required": false; }; "columnVirtualization": { "alias": "columnVirtualization"; "required": false; }; "virtualizationMouseWheelStep": { "alias": "virtualizationMouseWheelStep"; "required": false; }; "adjustVirtualHeights": { "alias": "adjustVirtualHeights"; "required": false; }; "templatingEngine": { "alias": "templatingEngine"; "required": false; }; "columns": { "alias": "columns"; "required": false; }; "dataSource": { "alias": "dataSource"; "required": false; }; "dataSourceUrl": { "alias": "dataSourceUrl"; "required": false; }; "dataSourceType": { "alias": "dataSourceType"; "required": false; }; "responseDataKey": { "alias": "responseDataKey"; "required": false; }; "responseTotalRecCountKey": { "alias": "responseTotalRecCountKey"; "required": false; }; "requestType": { "alias": "requestType"; "required": false; }; "responseContentType": { "alias": "responseContentType"; "required": false; }; "showHeader": { "alias": "showHeader"; "required": false; }; "showFooter": { "alias": "showFooter"; "required": false; }; "fixedHeaders": { "alias": "fixedHeaders"; "required": false; }; "fixedFooters": { "alias": "fixedFooters"; "required": false; }; "caption": { "alias": "caption"; "required": false; }; "features": { "alias": "features"; "required": false; }; "tabIndex": { "alias": "tabIndex"; "required": false; }; "localSchemaTransform": { "alias": "localSchemaTransform"; "required": false; }; "primaryKey": { "alias": "primaryKey"; "required": false; }; "serializeTransactionLog": { "alias": "serializeTransactionLog"; "required": false; }; "autoCommit": { "alias": "autoCommit"; "required": false; }; "aggregateTransactions": { "alias": "aggregateTransactions"; "required": false; }; "autoFormat": { "alias": "autoFormat"; "required": false; }; "renderCheckboxes": { "alias": "renderCheckboxes"; "required": false; }; "updateUrl": { "alias": "updateUrl"; "required": false; }; "restSettings": { "alias": "restSettings"; "required": false; }; "alternateRowStyles": { "alias": "alternateRowStyles"; "required": false; }; "autofitLastColumn": { "alias": "autofitLastColumn"; "required": false; }; "enableHoverStyles": { "alias": "enableHoverStyles"; "required": false; }; "enableUTCDates": { "alias": "enableUTCDates"; "required": false; }; "mergeUnboundColumns": { "alias": "mergeUnboundColumns"; "required": false; }; "jsonpRequest": { "alias": "jsonpRequest"; "required": false; }; "enableResizeContainerCheck": { "alias": "enableResizeContainerCheck"; "required": false; }; "featureChooserIconDisplay": { "alias": "featureChooserIconDisplay"; "required": false; }; "scrollSettings": { "alias": "scrollSettings"; "required": false; }; "indentation": { "alias": "indentation"; "required": false; }; "initialIndentationLevel": { "alias": "initialIndentationLevel"; "required": false; }; "showExpansionIndicator": { "alias": "showExpansionIndicator"; "required": false; }; "expandTooltipText": { "alias": "expandTooltipText"; "required": false; }; "collapseTooltipText": { "alias": "collapseTooltipText"; "required": false; }; "foreignKey": { "alias": "foreignKey"; "required": false; }; "initialExpandDepth": { "alias": "initialExpandDepth"; "required": false; }; "foreignKeyRootValue": { "alias": "foreignKeyRootValue"; "required": false; }; "renderExpansionIndicatorColumn": { "alias": "renderExpansionIndicatorColumn"; "required": false; }; "renderFirstDataCellFunction": { "alias": "renderFirstDataCellFunction"; "required": false; }; "childDataKey": { "alias": "childDataKey"; "required": false; }; "renderExpansionCellFunction": { "alias": "renderExpansionCellFunction"; "required": false; }; "enableRemoteLoadOnDemand": { "alias": "enableRemoteLoadOnDemand"; "required": false; }; "dataSourceSettings": { "alias": "dataSourceSettings"; "required": false; }; }, { "cellClick": "cellClick"; "cellRightClick": "cellRightClick"; "dataBinding": "dataBinding"; "dataBound": "dataBound"; "rendering": "rendering"; "rendered": "rendered"; "dataRendering": "dataRendering"; "dataRendered": "dataRendered"; "headerRendering": "headerRendering"; "headerRendered": "headerRendered"; "footerRendering": "footerRendering"; "footerRendered": "footerRendered"; "headerCellRendered": "headerCellRendered"; "rowsRendering": "rowsRendering"; "rowsRendered": "rowsRendered"; "schemaGenerated": "schemaGenerated"; "columnsCollectionModified": "columnsCollectionModified"; "requestError": "requestError"; "created": "created"; "destroyed": "destroyed"; "rowExpanding": "rowExpanding"; "rowExpanded": "rowExpanded"; "rowCollapsing": "rowCollapsing"; "rowCollapsed": "rowCollapsed"; }, never, ["*"], false, never>;
}
