/// <reference types="ignite-ui" />
import { ElementRef, IterableDiffers, KeyValueDiffers, ChangeDetectorRef, Renderer2 } from '@angular/core';
import { IgControlBase } from '../igcontrolbase/igcontrolbase';
import * as i0 from "@angular/core";
export declare class IgUploadComponent extends IgControlBase<IgUpload> {
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef);
    /**
     * Return jquery object of fileupload container - html DOM element
     */
    container(): void;
    /**
     * Returns the current widget element
     */
    widget(): void;
    /**
     * Hide finished files
     */
    clearAll(): void;
    /**
     * Append additional data field to formData(before submitting it to the server).
     * Usually this function is used in the handler of the event onFormDataSubmit.
     * If the browser supports HTML5 file API formData is instance of FormData,
     * otherwise(like IE10 and older) formData is jQuery representation of the <form> that should be submitted to the server
     *
     * @param formData    If the browser supports HTML5 file API formData is instance of FormData,
     * otherwise(like IE10 and older) formData is jQuery representation of the <form> that should be submitted to the server
     * @param field    Data field that should be appended to the formData. The object has 2 properties - value and name.
     * If the browser supports HTML5 the data field is appended to the formData object.
     * Otherwise it is appended as input hidden field to the <form>
     */
    addDataField(formData: object, field: object): void;
    /**
     * Append additional data fields to formData(before submitting it to the server).
     * Usually this function is used in the handler of the event onFormDataSubmit.
     * If the browser supports HTML5 file API formData is instance of FormData,
     * otherwise(like IE10 and older) formData is jQuery representation of the <form> that should be submitted to the server
     *
     * @param formData    If the browser supports HTML5 file API formData is instance of FormData,
     * otherwise(like IE10 and older) formData is jQuery representation of the <form> that should be submitted to the server
     * @param fields    Array of data fields that should be appended to the formData.
     * Each data field is object with 2 properties - value and name.
     * If the browser supports HTML5 these data fields are added to the formData.
     * Otherwise each of these data field is appended as input hidden field to the <form>
     */
    addDataFields(formData: object, fields: any[]): void;
    /**
     * Start uploading file as submitting form with the specified formNumber.
     *
     * @param formNumber    id of the upload form
     */
    startUpload(formNumber: number): void;
    /**
     * Cancel upload for the specified file id
     * 			 formNumber - id of the file to be canceled
     *
     * @param formNumber    id of the form which should be cancelled
     */
    cancelUpload(formNumber: number): void;
    /**
     * Destroy the widget
     */
    destroy(): void;
    /**
     * Returns the information about uploading files - all files uploaded/uploading/pending
     */
    getFileInfoData(): object;
    /**
     * Cancel all uploading and pending files
     */
    cancelAll(): void;
    /**
     * Returns the information about the file by specified file identifier.
     * It could be file which is uploading/uploaded or uploading is not started. If there isn"t file with the specified file id returns null
     *
     * @param fileIndex    unique identifier of the file
     */
    getFileInfo(fileIndex: number): object;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgUploadComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgUploadComponent, "ig-upload", never, { "widgetId": { "alias": "widgetId"; "required": false; }; "options": { "alias": "options"; "required": false; }; "changeDetectionInterval": { "alias": "changeDetectionInterval"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "create": { "alias": "create"; "required": false; }; "width": { "alias": "width"; "required": false; }; "height": { "alias": "height"; "required": false; }; "autostartupload": { "alias": "autostartupload"; "required": false; }; "labelUploadButton": { "alias": "labelUploadButton"; "required": false; }; "labelAddButton": { "alias": "labelAddButton"; "required": false; }; "labelClearAllButton": { "alias": "labelClearAllButton"; "required": false; }; "labelSummaryTemplate": { "alias": "labelSummaryTemplate"; "required": false; }; "labelSummaryProgressBarTemplate": { "alias": "labelSummaryProgressBarTemplate"; "required": false; }; "labelShowDetails": { "alias": "labelShowDetails"; "required": false; }; "labelHideDetails": { "alias": "labelHideDetails"; "required": false; }; "labelSummaryProgressButtonCancel": { "alias": "labelSummaryProgressButtonCancel"; "required": false; }; "labelSummaryProgressButtonContinue": { "alias": "labelSummaryProgressButtonContinue"; "required": false; }; "labelSummaryProgressButtonDone": { "alias": "labelSummaryProgressButtonDone"; "required": false; }; "labelProgressBarFileNameContinue": { "alias": "labelProgressBarFileNameContinue"; "required": false; }; "errorMessageMaxFileSizeExceeded": { "alias": "errorMessageMaxFileSizeExceeded"; "required": false; }; "errorMessageGetFileStatus": { "alias": "errorMessageGetFileStatus"; "required": false; }; "errorMessageCancelUpload": { "alias": "errorMessageCancelUpload"; "required": false; }; "errorMessageNoSuchFile": { "alias": "errorMessageNoSuchFile"; "required": false; }; "errorMessageOther": { "alias": "errorMessageOther"; "required": false; }; "errorMessageValidatingFileExtension": { "alias": "errorMessageValidatingFileExtension"; "required": false; }; "errorMessageAJAXRequestFileSize": { "alias": "errorMessageAJAXRequestFileSize"; "required": false; }; "errorMessageTryToRemoveNonExistingFile": { "alias": "errorMessageTryToRemoveNonExistingFile"; "required": false; }; "errorMessageTryToStartNonExistingFile": { "alias": "errorMessageTryToStartNonExistingFile"; "required": false; }; "errorMessageMaxUploadedFiles": { "alias": "errorMessageMaxUploadedFiles"; "required": false; }; "errorMessageMaxSimultaneousFiles": { "alias": "errorMessageMaxSimultaneousFiles"; "required": false; }; "errorMessageDropMultipleFilesWhenSingleModel": { "alias": "errorMessageDropMultipleFilesWhenSingleModel"; "required": false; }; "uploadUrl": { "alias": "uploadUrl"; "required": false; }; "progressUrl": { "alias": "progressUrl"; "required": false; }; "allowedExtensions": { "alias": "allowedExtensions"; "required": false; }; "showFileExtensionIcon": { "alias": "showFileExtensionIcon"; "required": false; }; "css": { "alias": "css"; "required": false; }; "fileExtensionIcons": { "alias": "fileExtensionIcons"; "required": false; }; "mode": { "alias": "mode"; "required": false; }; "multipleFiles": { "alias": "multipleFiles"; "required": false; }; "maxUploadedFiles": { "alias": "maxUploadedFiles"; "required": false; }; "maxSimultaneousFilesUploads": { "alias": "maxSimultaneousFilesUploads"; "required": false; }; "fileSizeMetric": { "alias": "fileSizeMetric"; "required": false; }; "controlId": { "alias": "controlId"; "required": false; }; "fileSizeDecimalDisplay": { "alias": "fileSizeDecimalDisplay"; "required": false; }; "maxFileSize": { "alias": "maxFileSize"; "required": false; }; }, { "fileSelecting": "fileSelecting"; "fileSelected": "fileSelected"; "fileUploading": "fileUploading"; "fileUploaded": "fileUploaded"; "fileUploadAborted": "fileUploadAborted"; "cancelAllClicked": "cancelAllClicked"; "onError": "onError"; "fileExtensionsValidating": "fileExtensionsValidating"; "onXHRLoad": "onXHRLoad"; "onFormDataSubmit": "onFormDataSubmit"; }, never, ["*"], false, never>;
}
