/// <reference types="ignite-ui" />
import { ElementRef, IterableDiffers, KeyValueDiffers, ChangeDetectorRef, Renderer2 } from '@angular/core';
import { IgControlBase } from '../igcontrolbase/igcontrolbase';
import * as i0 from "@angular/core";
export declare class IgVideoPlayerComponent extends IgControlBase<IgVideoPlayer> {
    constructor(el: ElementRef, renderer: Renderer2, differs: IterableDiffers, kvalDiffers: KeyValueDiffers, cdr: ChangeDetectorRef);
    /**
     * Returns the element on which the widget was instantiated
     */
    widget(): void;
    /**
     * Hide the add message if shown.
     */
    hideAdMessage(): void;
    /**
     * Play a linked commercial for this video.
     *
     * @param commercial     Specify the linked commercial to play.
     */
    playCommercial(commercial: object): void;
    /**
     * Shows the ad banner, if there is such.
     *
     * @param index    Specify the index of the banner from the banners array.
     */
    showBanner(index: number): void;
    /**
     * Hide the ad banner, if there is such.
     *
     * @param index    Specify the index of the banner from the banners array.
     */
    hideBanner(index: number): void;
    /**
     * Resets the commercials, to be shown again.
     */
    resetCommercialsShow(): void;
    /**
     * Toggle control play state. If video is playing it will pause, if video is paused it will play.
     */
    togglePlay(): void;
    /**
     * Start playing current loaded video if any.
     */
    play(): void;
    /**
     * Pause the currently playing video if any.
     */
    pause(): void;
    /**
     * Gets/Sets the current time of the playing video.
     *
     * @param val     Specify the playback position in seconds to navigate to.
     */
    currentTime(val: number): number;
    /**
     * Get a screenshot of the current video frame.
     * It returns a canvas object that you can position and show on the page. This depends on the browser support for canvas.
     *
     * @param scaleFactor    Specify scale factor between 0 and 1.
     */
    screenshot(scaleFactor?: number): object;
    /**
     * Get whether the current browser supports video tag.
     */
    supportsVideo(): boolean;
    /**
     * Get whether the current browser supports H.264 codec.
     */
    supportsH264BaselineVideo(): boolean;
    /**
     * Get whether the current browser supports Theora codec.
     */
    supportsOggTheoraVideo(): boolean;
    /**
     * Get whether the current browser supports WEBM codec.
     */
    supportsWebmVideo(): boolean;
    /**
     * Returns whether the currently played video is paused.
     */
    paused(): boolean;
    /**
     * Get whether the current played video has ended.
     */
    ended(): boolean;
    /**
     * Get the current duration of the played video. It may be NaN if duration is still not loaded or the video is a live stream.
     */
    duration(): number;
    /**
     * Get whether the player is seeking to find the new playback position specified.
     */
    seeking(): boolean;
    /**
     * Destroys the widget.
     */
    destroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgVideoPlayerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgVideoPlayerComponent, "ig-video-player", never, { "widgetId": { "alias": "widgetId"; "required": false; }; "options": { "alias": "options"; "required": false; }; "changeDetectionInterval": { "alias": "changeDetectionInterval"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "create": { "alias": "create"; "required": false; }; "sources": { "alias": "sources"; "required": false; }; "width": { "alias": "width"; "required": false; }; "height": { "alias": "height"; "required": false; }; "posterUrl": { "alias": "posterUrl"; "required": false; }; "preload": { "alias": "preload"; "required": false; }; "autoplay": { "alias": "autoplay"; "required": false; }; "autohide": { "alias": "autohide"; "required": false; }; "volumeAutohideDelay": { "alias": "volumeAutohideDelay"; "required": false; }; "centerButtonHideDelay": { "alias": "centerButtonHideDelay"; "required": false; }; "loop": { "alias": "loop"; "required": false; }; "browserControls": { "alias": "browserControls"; "required": false; }; "fullscreen": { "alias": "fullscreen"; "required": false; }; "volume": { "alias": "volume"; "required": false; }; "muted": { "alias": "muted"; "required": false; }; "title": { "alias": "title"; "required": false; }; "showSeekTime": { "alias": "showSeekTime"; "required": false; }; "progressLabelFormat": { "alias": "progressLabelFormat"; "required": false; }; "bookmarks": { "alias": "bookmarks"; "required": false; }; "relatedVideos": { "alias": "relatedVideos"; "required": false; }; "banners": { "alias": "banners"; "required": false; }; "commercials": { "alias": "commercials"; "required": false; }; }, { "ended": "ended"; "playing": "playing"; "paused": "paused"; "buffering": "buffering"; "progress": "progress"; "waiting": "waiting"; "bookmarkHit": "bookmarkHit"; "bookmarkClick": "bookmarkClick"; "enterFullScreen": "enterFullScreen"; "exitFullScreen": "exitFullScreen"; "relatedVideoClick": "relatedVideoClick"; "bannerVisible": "bannerVisible"; "bannerHidden": "bannerHidden"; "bannerClick": "bannerClick"; "browserNotSupported": "browserNotSupported"; }, never, ["*"], false, never>;
}
